﻿using System;
using System.Drawing;
using System.Linq;
using System.Collections.Generic;
using System.Windows.Forms;
using OpcLabs.BaseLib.Diagnostics;
using OpcLabs.BaseLib.Forms.Browsing;
using OpcLabs.BaseLib.Forms.Browsing.Parts;
using System.Diagnostics.CodeAnalysis;
using OpcLabs.BaseLib.Forms.Browsing.Extensions;
using OpcLabs.BaseLib.Forms.Common;

namespace OpcLabs.BaseLibFormsTestApp
{
    //TODO: move to ...

    class NodePresentationTestSample : INodePresentation
    {
        #region Static Private Fields
        static private readonly Guid TypeColumnGuid = Guid.NewGuid();
        static private readonly Guid FolderIconGuid = new Guid("004CE0AA-78FF-4DB2-941E-B705D58E166E");
        static private readonly Guid NetworkIconGuid = new Guid("19B235F9-4E7A-4DFA-B144-043211808FED");
        static private readonly Guid WorkGroupIconGuid = new Guid("BF9204C7-3165-4542-9E79-917B6741BC2A");
        #endregion

        #region INodePresentation Members

        public bool CreateNode(object parentNode, Type type, out object nodeCreated)
        {
            Always.RequiresNotNull(parentNode, nameof(parentNode));
            Always.RequiresNotNull(type, nameof(type));
            Check.Ensures(Check.Result<bool>() || (Check.ValueAtReturn(out nodeCreated) == null));

            if (type.Name == "Folder")
            {
                var result = (MessageBox.Show("Folder name by time?", "", MessageBoxButtons.YesNoCancel));
                if (result == DialogResult.Yes)
                {
                    nodeCreated = new Folder(DateTime.Now.ToShortTimeString());
                    return true;
                }
                if (result == DialogResult.Cancel)
                {
                    nodeCreated = null;
                    return true;
                }
            }
            nodeCreated = null;
            return false;
        }

        public bool EditNode(IEnumerable<object> oldNodePath, IBrowsePresentationHost browsePresentationHost, out object newNode)
        {
            Always.RequiresNotNull(oldNodePath, nameof(oldNodePath));
            IEnumerable<object> enumeratedNodePath = oldNodePath as IList<object> ?? oldNodePath.ToList();
            Always.Requires(Check.ForAll(enumeratedNodePath, o => o != null));
            Always.RequiresNotNull(browsePresentationHost, nameof(browsePresentationHost));
            Check.Ensures(Check.Result<bool>() || (Check.ValueAtReturn(out newNode) == null));

            newNode = null;
            return false;
        }

        public IEnumerable<BrowseStateIcon> GetBrowseStateIcons(Guid iconGuid)
        {
            Check.Ensures(Check.Result<IEnumerable<BrowseStateIcon>>() != null);
            // ReSharper disable once AssignNullToNotNullAttribute
            Check.Ensures(Check.ForAll(Check.Result<IEnumerable<BrowseStateIcon>>(), browseIcon => browseIcon != null));

            var list = new List<BrowseStateIcon>();


            if (iconGuid == FolderIconGuid)
            {
                list.Add(new BrowseStateIcon(BrowseIcon.ConvertByteToBitmap(
                    new byte[] { 0xff, 0xd8, 0xff, 0xe0, 0x0, 0x10, 0x4a, 0x46, 0x49, 0x46, 0x0, 0x1, 0x1, 0x1, 0x0, 0x60, 0x0, 0x60, 0x0, 0x0, 0xff, 0xdb, 0x0, 0x43, 0x0, 0x8, 0x6, 0x6, 0x7, 0x6, 0x5, 0x8, 0x7, 0x7, 0x7, 0x9, 0x9, 0x8, 0xa, 0xc, 0x14, 0xd, 0xc, 0xb, 0xb, 0xc, 0x19, 0x12, 0x13, 0xf, 0x14, 0x1d, 0x1a, 0x1f, 0x1e, 0x1d, 0x1a, 0x1c, 0x1c, 0x20, 0x24, 0x2e, 0x27, 0x20, 0x22, 0x2c, 0x23, 0x1c, 0x1c, 0x28, 0x37, 0x29, 0x2c, 0x30, 0x31, 0x34, 0x34, 0x34, 0x1f, 0x27, 0x39, 0x3d, 0x38, 0x32, 0x3c, 0x2e, 0x33, 0x34, 0x32, 0xff, 0xdb, 0x0, 0x43, 0x1, 0x9, 0x9, 0x9, 0xc, 0xb, 0xc, 0x18, 0xd, 0xd, 0x18, 0x32, 0x21, 0x1c, 0x21, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0xff, 0xc0, 0x0, 0x11, 0x8, 0x0, 0x10, 0x0, 0x10, 0x3, 0x1, 0x22, 0x0, 0x2, 0x11, 0x1, 0x3, 0x11, 0x1, 0xff, 0xc4, 0x0, 0x1f, 0x0, 0x0, 0x1, 0x5, 0x1, 0x1, 0x1, 0x1, 0x1, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xff, 0xc4, 0x0, 0xb5, 0x10, 0x0, 0x2, 0x1, 0x3, 0x3, 0x2, 0x4, 0x3, 0x5, 0x5, 0x4, 0x4, 0x0, 0x0, 0x1, 0x7d, 0x1, 0x2, 0x3, 0x0, 0x4, 0x11, 0x5, 0x12, 0x21, 0x31, 0x41, 0x6, 0x13, 0x51, 0x61, 0x7, 0x22, 0x71, 0x14, 0x32, 0x81, 0x91, 0xa1, 0x8, 0x23, 0x42, 0xb1, 0xc1, 0x15, 0x52, 0xd1, 0xf0, 0x24, 0x33, 0x62, 0x72, 0x82, 0x9, 0xa, 0x16, 0x17, 0x18, 0x19, 0x1a, 0x25, 0x26, 0x27, 0x28, 0x29, 0x2a, 0x34, 0x35, 0x36, 0x37, 0x38, 0x39, 0x3a, 0x43, 0x44, 0x45, 0x46, 0x47, 0x48, 0x49, 0x4a, 0x53, 0x54, 0x55, 0x56, 0x57, 0x58, 0x59, 0x5a, 0x63, 0x64, 0x65, 0x66, 0x67, 0x68, 0x69, 0x6a, 0x73, 0x74, 0x75, 0x76, 0x77, 0x78, 0x79, 0x7a, 0x83, 0x84, 0x85, 0x86, 0x87, 0x88, 0x89, 0x8a, 0x92, 0x93, 0x94, 0x95, 0x96, 0x97, 0x98, 0x99, 0x9a, 0xa2, 0xa3, 0xa4, 0xa5, 0xa6, 0xa7, 0xa8, 0xa9, 0xaa, 0xb2, 0xb3, 0xb4, 0xb5, 0xb6, 0xb7, 0xb8, 0xb9, 0xba, 0xc2, 0xc3, 0xc4, 0xc5, 0xc6, 0xc7, 0xc8, 0xc9, 0xca, 0xd2, 0xd3, 0xd4, 0xd5, 0xd6, 0xd7, 0xd8, 0xd9, 0xda, 0xe1, 0xe2, 0xe3, 0xe4, 0xe5, 0xe6, 0xe7, 0xe8, 0xe9, 0xea, 0xf1, 0xf2, 0xf3, 0xf4, 0xf5, 0xf6, 0xf7, 0xf8, 0xf9, 0xfa, 0xff, 0xc4, 0x0, 0x1f, 0x1, 0x0, 0x3, 0x1, 0x1, 0x1, 0x1, 0x1, 0x1, 0x1, 0x1, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xff, 0xc4, 0x0, 0xb5, 0x11, 0x0, 0x2, 0x1, 0x2, 0x4, 0x4, 0x3, 0x4, 0x7, 0x5, 0x4, 0x4, 0x0, 0x1, 0x2, 0x77, 0x0, 0x1, 0x2, 0x3, 0x11, 0x4, 0x5, 0x21, 0x31, 0x6, 0x12, 0x41, 0x51, 0x7, 0x61, 0x71, 0x13, 0x22, 0x32, 0x81, 0x8, 0x14, 0x42, 0x91, 0xa1, 0xb1, 0xc1, 0x9, 0x23, 0x33, 0x52, 0xf0, 0x15, 0x62, 0x72, 0xd1, 0xa, 0x16, 0x24, 0x34, 0xe1, 0x25, 0xf1, 0x17, 0x18, 0x19, 0x1a, 0x26, 0x27, 0x28, 0x29, 0x2a, 0x35, 0x36, 0x37, 0x38, 0x39, 0x3a, 0x43, 0x44, 0x45, 0x46, 0x47, 0x48, 0x49, 0x4a, 0x53, 0x54, 0x55, 0x56, 0x57, 0x58, 0x59, 0x5a, 0x63, 0x64, 0x65, 0x66, 0x67, 0x68, 0x69, 0x6a, 0x73, 0x74, 0x75, 0x76, 0x77, 0x78, 0x79, 0x7a, 0x82, 0x83, 0x84, 0x85, 0x86, 0x87, 0x88, 0x89, 0x8a, 0x92, 0x93, 0x94, 0x95, 0x96, 0x97, 0x98, 0x99, 0x9a, 0xa2, 0xa3, 0xa4, 0xa5, 0xa6, 0xa7, 0xa8, 0xa9, 0xaa, 0xb2, 0xb3, 0xb4, 0xb5, 0xb6, 0xb7, 0xb8, 0xb9, 0xba, 0xc2, 0xc3, 0xc4, 0xc5, 0xc6, 0xc7, 0xc8, 0xc9, 0xca, 0xd2, 0xd3, 0xd4, 0xd5, 0xd6, 0xd7, 0xd8, 0xd9, 0xda, 0xe2, 0xe3, 0xe4, 0xe5, 0xe6, 0xe7, 0xe8, 0xe9, 0xea, 0xf2, 0xf3, 0xf4, 0xf5, 0xf6, 0xf7, 0xf8, 0xf9, 0xfa, 0xff, 0xda, 0x0, 0xc, 0x3, 0x1, 0x0, 0x2, 0x11, 0x3, 0x11, 0x0, 0x3f, 0x0, 0xf6, 0x4, 0xd4, 0xa5, 0xb8, 0x85, 0x6e, 0x21, 0xb9, 0x9f, 0xcc, 0x65, 0xf, 0xe4, 0xa5, 0xb9, 0x92, 0x25, 0x24, 0x3, 0xb4, 0x95, 0x42, 0x73, 0x82, 0x39, 0xcf, 0xbe, 0x31, 0xc5, 0x2b, 0xf8, 0x8d, 0xad, 0xae, 0x22, 0x5b, 0xdb, 0x36, 0x86, 0xdd, 0xf3, 0xbe, 0xe3, 0xe7, 0xb, 0x19, 0xc8, 0x3, 0x76, 0xf4, 0x5e, 0x9, 0x38, 0xc8, 0xcf, 0xeb, 0x5c, 0xfc, 0x7a, 0xcd, 0xc6, 0x81, 0xbe, 0xc9, 0xb4, 0xbb, 0xf9, 0xa4, 0xc, 0xb, 0x34, 0x36, 0xe5, 0xd7, 0x84, 0x55, 0xe0, 0xe4, 0x7a, 0x1f, 0xd2, 0xb3, 0xf5, 0xdd, 0x6a, 0xf7, 0x5f, 0xd3, 0xa5, 0xd3, 0xa1, 0xd1, 0xb5, 0x14, 0x79, 0xd4, 0x22, 0x97, 0xb6, 0x2a, 0xa0, 0xf9, 0x88, 0x72, 0x49, 0x3c, 0xc, 0x29, 0xaf, 0x16, 0x96, 0x23, 0x14, 0x9a, 0x4e, 0x2f, 0xee, 0xff, 0x0, 0x80, 0x76, 0x4a, 0x9d, 0x3e, 0xea, 0xde, 0xa7, 0xff, 0xd9 }),
                    Color.Magenta, BrowseIconStates.None));
                list.Add(new BrowseStateIcon(BrowseIcon.ConvertByteToBitmap(
                    new byte[] { 0xff, 0xd8, 0xff, 0xe0, 0x0, 0x10, 0x4a, 0x46, 0x49, 0x46, 0x0, 0x1, 0x1, 0x1, 0x0, 0x60, 0x0, 0x60, 0x0, 0x0, 0xff, 0xdb, 0x0, 0x43, 0x0, 0x8, 0x6, 0x6, 0x7, 0x6, 0x5, 0x8, 0x7, 0x7, 0x7, 0x9, 0x9, 0x8, 0xa, 0xc, 0x14, 0xd, 0xc, 0xb, 0xb, 0xc, 0x19, 0x12, 0x13, 0xf, 0x14, 0x1d, 0x1a, 0x1f, 0x1e, 0x1d, 0x1a, 0x1c, 0x1c, 0x20, 0x24, 0x2e, 0x27, 0x20, 0x22, 0x2c, 0x23, 0x1c, 0x1c, 0x28, 0x37, 0x29, 0x2c, 0x30, 0x31, 0x34, 0x34, 0x34, 0x1f, 0x27, 0x39, 0x3d, 0x38, 0x32, 0x3c, 0x2e, 0x33, 0x34, 0x32, 0xff, 0xdb, 0x0, 0x43, 0x1, 0x9, 0x9, 0x9, 0xc, 0xb, 0xc, 0x18, 0xd, 0xd, 0x18, 0x32, 0x21, 0x1c, 0x21, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0xff, 0xc0, 0x0, 0x11, 0x8, 0x0, 0x10, 0x0, 0x10, 0x3, 0x1, 0x22, 0x0, 0x2, 0x11, 0x1, 0x3, 0x11, 0x1, 0xff, 0xc4, 0x0, 0x1f, 0x0, 0x0, 0x1, 0x5, 0x1, 0x1, 0x1, 0x1, 0x1, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xff, 0xc4, 0x0, 0xb5, 0x10, 0x0, 0x2, 0x1, 0x3, 0x3, 0x2, 0x4, 0x3, 0x5, 0x5, 0x4, 0x4, 0x0, 0x0, 0x1, 0x7d, 0x1, 0x2, 0x3, 0x0, 0x4, 0x11, 0x5, 0x12, 0x21, 0x31, 0x41, 0x6, 0x13, 0x51, 0x61, 0x7, 0x22, 0x71, 0x14, 0x32, 0x81, 0x91, 0xa1, 0x8, 0x23, 0x42, 0xb1, 0xc1, 0x15, 0x52, 0xd1, 0xf0, 0x24, 0x33, 0x62, 0x72, 0x82, 0x9, 0xa, 0x16, 0x17, 0x18, 0x19, 0x1a, 0x25, 0x26, 0x27, 0x28, 0x29, 0x2a, 0x34, 0x35, 0x36, 0x37, 0x38, 0x39, 0x3a, 0x43, 0x44, 0x45, 0x46, 0x47, 0x48, 0x49, 0x4a, 0x53, 0x54, 0x55, 0x56, 0x57, 0x58, 0x59, 0x5a, 0x63, 0x64, 0x65, 0x66, 0x67, 0x68, 0x69, 0x6a, 0x73, 0x74, 0x75, 0x76, 0x77, 0x78, 0x79, 0x7a, 0x83, 0x84, 0x85, 0x86, 0x87, 0x88, 0x89, 0x8a, 0x92, 0x93, 0x94, 0x95, 0x96, 0x97, 0x98, 0x99, 0x9a, 0xa2, 0xa3, 0xa4, 0xa5, 0xa6, 0xa7, 0xa8, 0xa9, 0xaa, 0xb2, 0xb3, 0xb4, 0xb5, 0xb6, 0xb7, 0xb8, 0xb9, 0xba, 0xc2, 0xc3, 0xc4, 0xc5, 0xc6, 0xc7, 0xc8, 0xc9, 0xca, 0xd2, 0xd3, 0xd4, 0xd5, 0xd6, 0xd7, 0xd8, 0xd9, 0xda, 0xe1, 0xe2, 0xe3, 0xe4, 0xe5, 0xe6, 0xe7, 0xe8, 0xe9, 0xea, 0xf1, 0xf2, 0xf3, 0xf4, 0xf5, 0xf6, 0xf7, 0xf8, 0xf9, 0xfa, 0xff, 0xc4, 0x0, 0x1f, 0x1, 0x0, 0x3, 0x1, 0x1, 0x1, 0x1, 0x1, 0x1, 0x1, 0x1, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xff, 0xc4, 0x0, 0xb5, 0x11, 0x0, 0x2, 0x1, 0x2, 0x4, 0x4, 0x3, 0x4, 0x7, 0x5, 0x4, 0x4, 0x0, 0x1, 0x2, 0x77, 0x0, 0x1, 0x2, 0x3, 0x11, 0x4, 0x5, 0x21, 0x31, 0x6, 0x12, 0x41, 0x51, 0x7, 0x61, 0x71, 0x13, 0x22, 0x32, 0x81, 0x8, 0x14, 0x42, 0x91, 0xa1, 0xb1, 0xc1, 0x9, 0x23, 0x33, 0x52, 0xf0, 0x15, 0x62, 0x72, 0xd1, 0xa, 0x16, 0x24, 0x34, 0xe1, 0x25, 0xf1, 0x17, 0x18, 0x19, 0x1a, 0x26, 0x27, 0x28, 0x29, 0x2a, 0x35, 0x36, 0x37, 0x38, 0x39, 0x3a, 0x43, 0x44, 0x45, 0x46, 0x47, 0x48, 0x49, 0x4a, 0x53, 0x54, 0x55, 0x56, 0x57, 0x58, 0x59, 0x5a, 0x63, 0x64, 0x65, 0x66, 0x67, 0x68, 0x69, 0x6a, 0x73, 0x74, 0x75, 0x76, 0x77, 0x78, 0x79, 0x7a, 0x82, 0x83, 0x84, 0x85, 0x86, 0x87, 0x88, 0x89, 0x8a, 0x92, 0x93, 0x94, 0x95, 0x96, 0x97, 0x98, 0x99, 0x9a, 0xa2, 0xa3, 0xa4, 0xa5, 0xa6, 0xa7, 0xa8, 0xa9, 0xaa, 0xb2, 0xb3, 0xb4, 0xb5, 0xb6, 0xb7, 0xb8, 0xb9, 0xba, 0xc2, 0xc3, 0xc4, 0xc5, 0xc6, 0xc7, 0xc8, 0xc9, 0xca, 0xd2, 0xd3, 0xd4, 0xd5, 0xd6, 0xd7, 0xd8, 0xd9, 0xda, 0xe2, 0xe3, 0xe4, 0xe5, 0xe6, 0xe7, 0xe8, 0xe9, 0xea, 0xf2, 0xf3, 0xf4, 0xf5, 0xf6, 0xf7, 0xf8, 0xf9, 0xfa, 0xff, 0xda, 0x0, 0xc, 0x3, 0x1, 0x0, 0x2, 0x11, 0x3, 0x11, 0x0, 0x3f, 0x0, 0xf6, 0x4, 0xd4, 0xa5, 0xb8, 0x85, 0x6e, 0x21, 0xb9, 0x9f, 0xcc, 0x65, 0xf, 0xe4, 0xa5, 0xb9, 0x92, 0x25, 0x24, 0x3, 0xb4, 0x95, 0x42, 0x73, 0x82, 0x39, 0xcf, 0xbe, 0x31, 0xc5, 0x2b, 0xf8, 0x8d, 0xad, 0xae, 0x22, 0x5b, 0xdb, 0x36, 0x86, 0xdd, 0xf3, 0xbe, 0xe3, 0xe7, 0xb, 0x19, 0xc8, 0x3, 0x76, 0xf4, 0x5e, 0x9, 0x38, 0xc8, 0xcf, 0xeb, 0x5c, 0xfc, 0x7a, 0xcd, 0xc6, 0x81, 0xbe, 0xc9, 0xb4, 0xbb, 0xf9, 0xa4, 0xc, 0xb, 0x34, 0x36, 0xe5, 0xd7, 0x84, 0x55, 0xe0, 0xe4, 0x7a, 0x1f, 0xd2, 0xb3, 0xf5, 0xdd, 0x6a, 0xf7, 0x5f, 0xd3, 0xa5, 0xd3, 0xa1, 0xd1, 0xb5, 0x14, 0x79, 0xd4, 0x22, 0x97, 0xb6, 0x2a, 0xa0, 0xf9, 0x88, 0x72, 0x49, 0x3c, 0xc, 0x29, 0xaf, 0x16, 0x96, 0x23, 0x14, 0x9a, 0x4e, 0x2f, 0xee, 0xff, 0x0, 0x80, 0x76, 0x4a, 0x9d, 0x3e, 0xea, 0xde, 0xa7, 0xff, 0xd9 }),
                    Color.Magenta, BrowseIconStates.Tree | BrowseIconStates.ManuallyAdded));
                list.Add(new BrowseStateIcon(BrowseIcon.ConvertByteToBitmap(
                    //                    new byte[] { 0xff, 0xd8, 0xff, 0xe0, 0x0, 0x10, 0x4a, 0x46, 0x49, 0x46, 0x0, 0x1, 0x1, 0x1, 0x0, 0x60, 0x0, 0x60, 0x0, 0x0, 0xff, 0xdb, 0x0, 0x43, 0x0, 0x8, 0x6, 0x6, 0x7, 0x6, 0x5, 0x8, 0x7, 0x7, 0x7, 0x9, 0x9, 0x8, 0xa, 0xc, 0x14, 0xd, 0xc, 0xb, 0xb, 0xc, 0x19, 0x12, 0x13, 0xf, 0x14, 0x1d, 0x1a, 0x1f, 0x1e, 0x1d, 0x1a, 0x1c, 0x1c, 0x20, 0x24, 0x2e, 0x27, 0x20, 0x22, 0x2c, 0x23, 0x1c, 0x1c, 0x28, 0x37, 0x29, 0x2c, 0x30, 0x31, 0x34, 0x34, 0x34, 0x1f, 0x27, 0x39, 0x3d, 0x38, 0x32, 0x3c, 0x2e, 0x33, 0x34, 0x32, 0xff, 0xdb, 0x0, 0x43, 0x1, 0x9, 0x9, 0x9, 0xc, 0xb, 0xc, 0x18, 0xd, 0xd, 0x18, 0x32, 0x21, 0x1c, 0x21, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0xff, 0xc0, 0x0, 0x11, 0x8, 0x0, 0x10, 0x0, 0x10, 0x3, 0x1, 0x22, 0x0, 0x2, 0x11, 0x1, 0x3, 0x11, 0x1, 0xff, 0xc4, 0x0, 0x1f, 0x0, 0x0, 0x1, 0x5, 0x1, 0x1, 0x1, 0x1, 0x1, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xff, 0xc4, 0x0, 0xb5, 0x10, 0x0, 0x2, 0x1, 0x3, 0x3, 0x2, 0x4, 0x3, 0x5, 0x5, 0x4, 0x4, 0x0, 0x0, 0x1, 0x7d, 0x1, 0x2, 0x3, 0x0, 0x4, 0x11, 0x5, 0x12, 0x21, 0x31, 0x41, 0x6, 0x13, 0x51, 0x61, 0x7, 0x22, 0x71, 0x14, 0x32, 0x81, 0x91, 0xa1, 0x8, 0x23, 0x42, 0xb1, 0xc1, 0x15, 0x52, 0xd1, 0xf0, 0x24, 0x33, 0x62, 0x72, 0x82, 0x9, 0xa, 0x16, 0x17, 0x18, 0x19, 0x1a, 0x25, 0x26, 0x27, 0x28, 0x29, 0x2a, 0x34, 0x35, 0x36, 0x37, 0x38, 0x39, 0x3a, 0x43, 0x44, 0x45, 0x46, 0x47, 0x48, 0x49, 0x4a, 0x53, 0x54, 0x55, 0x56, 0x57, 0x58, 0x59, 0x5a, 0x63, 0x64, 0x65, 0x66, 0x67, 0x68, 0x69, 0x6a, 0x73, 0x74, 0x75, 0x76, 0x77, 0x78, 0x79, 0x7a, 0x83, 0x84, 0x85, 0x86, 0x87, 0x88, 0x89, 0x8a, 0x92, 0x93, 0x94, 0x95, 0x96, 0x97, 0x98, 0x99, 0x9a, 0xa2, 0xa3, 0xa4, 0xa5, 0xa6, 0xa7, 0xa8, 0xa9, 0xaa, 0xb2, 0xb3, 0xb4, 0xb5, 0xb6, 0xb7, 0xb8, 0xb9, 0xba, 0xc2, 0xc3, 0xc4, 0xc5, 0xc6, 0xc7, 0xc8, 0xc9, 0xca, 0xd2, 0xd3, 0xd4, 0xd5, 0xd6, 0xd7, 0xd8, 0xd9, 0xda, 0xe1, 0xe2, 0xe3, 0xe4, 0xe5, 0xe6, 0xe7, 0xe8, 0xe9, 0xea, 0xf1, 0xf2, 0xf3, 0xf4, 0xf5, 0xf6, 0xf7, 0xf8, 0xf9, 0xfa, 0xff, 0xc4, 0x0, 0x1f, 0x1, 0x0, 0x3, 0x1, 0x1, 0x1, 0x1, 0x1, 0x1, 0x1, 0x1, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xff, 0xc4, 0x0, 0xb5, 0x11, 0x0, 0x2, 0x1, 0x2, 0x4, 0x4, 0x3, 0x4, 0x7, 0x5, 0x4, 0x4, 0x0, 0x1, 0x2, 0x77, 0x0, 0x1, 0x2, 0x3, 0x11, 0x4, 0x5, 0x21, 0x31, 0x6, 0x12, 0x41, 0x51, 0x7, 0x61, 0x71, 0x13, 0x22, 0x32, 0x81, 0x8, 0x14, 0x42, 0x91, 0xa1, 0xb1, 0xc1, 0x9, 0x23, 0x33, 0x52, 0xf0, 0x15, 0x62, 0x72, 0xd1, 0xa, 0x16, 0x24, 0x34, 0xe1, 0x25, 0xf1, 0x17, 0x18, 0x19, 0x1a, 0x26, 0x27, 0x28, 0x29, 0x2a, 0x35, 0x36, 0x37, 0x38, 0x39, 0x3a, 0x43, 0x44, 0x45, 0x46, 0x47, 0x48, 0x49, 0x4a, 0x53, 0x54, 0x55, 0x56, 0x57, 0x58, 0x59, 0x5a, 0x63, 0x64, 0x65, 0x66, 0x67, 0x68, 0x69, 0x6a, 0x73, 0x74, 0x75, 0x76, 0x77, 0x78, 0x79, 0x7a, 0x82, 0x83, 0x84, 0x85, 0x86, 0x87, 0x88, 0x89, 0x8a, 0x92, 0x93, 0x94, 0x95, 0x96, 0x97, 0x98, 0x99, 0x9a, 0xa2, 0xa3, 0xa4, 0xa5, 0xa6, 0xa7, 0xa8, 0xa9, 0xaa, 0xb2, 0xb3, 0xb4, 0xb5, 0xb6, 0xb7, 0xb8, 0xb9, 0xba, 0xc2, 0xc3, 0xc4, 0xc5, 0xc6, 0xc7, 0xc8, 0xc9, 0xca, 0xd2, 0xd3, 0xd4, 0xd5, 0xd6, 0xd7, 0xd8, 0xd9, 0xda, 0xe2, 0xe3, 0xe4, 0xe5, 0xe6, 0xe7, 0xe8, 0xe9, 0xea, 0xf2, 0xf3, 0xf4, 0xf5, 0xf6, 0xf7, 0xf8, 0xf9, 0xfa, 0xff, 0xda, 0x0, 0xc, 0x3, 0x1, 0x0, 0x2, 0x11, 0x3, 0x11, 0x0, 0x3f, 0x0, 0xf4, 0x6b, 0xff, 0x0, 0x11, 0xbd, 0xde, 0xbf, 0xa9, 0x58, 0x36, 0xe1, 0x69, 0x64, 0xa5, 0x5d, 0x63, 0x7d, 0xa7, 0x18, 0x4, 0xbb, 0x1e, 0xc0, 0x67, 0x3, 0x3c, 0x71, 0x5c, 0xce, 0x87, 0xe3, 0xd, 0x43, 0x4a, 0xf1, 0xba, 0xe8, 0xd3, 0xc9, 0x34, 0xb6, 0xb2, 0xc9, 0xe5, 0xb4, 0x53, 0x1c, 0x98, 0xcf, 0x62, 0x33, 0xc8, 0xed, 0xc7, 0x4a, 0xed, 0xa6, 0xd1, 0xad, 0x74, 0x9f, 0x12, 0x6a, 0x1a, 0xcb, 0xed, 0x36, 0xfa, 0x8c, 0x2a, 0x93, 0xac, 0xa0, 0x14, 0x57, 0x5e, 0x84, 0xfd, 0x47, 0xaf, 0xa0, 0xac, 0x49, 0xb4, 0xcd, 0x37, 0x5f, 0xf1, 0xe6, 0x9b, 0x71, 0x67, 0x2a, 0x49, 0xf6, 0x48, 0x8c, 0x97, 0x32, 0xc0, 0x3e, 0x46, 0x20, 0xfc, 0x8b, 0x9e, 0xe7, 0xad, 0x5b, 0x50, 0x8b, 0x7c, 0x8f, 0x7b, 0x7e, 0x5a, 0xaf, 0xbf, 0xa9, 0xc5, 0xf5, 0x69, 0xb9, 0xaa, 0x8e, 0x5a, 0xa7, 0xf7, 0xa3, 0xff, 0xd9 }),
                    new byte[] { 0xff, 0xd8, 0xff, 0xe0, 0x0, 0x10, 0x4a, 0x46, 0x49, 0x46, 0x0, 0x1, 0x1, 0x1, 0x0, 0x60, 0x0, 0x60, 0x0, 0x0, 0xff, 0xdb, 0x0, 0x43, 0x0, 0x8, 0x6, 0x6, 0x7, 0x6, 0x5, 0x8, 0x7, 0x7, 0x7, 0x9, 0x9, 0x8, 0xa, 0xc, 0x14, 0xd, 0xc, 0xb, 0xb, 0xc, 0x19, 0x12, 0x13, 0xf, 0x14, 0x1d, 0x1a, 0x1f, 0x1e, 0x1d, 0x1a, 0x1c, 0x1c, 0x20, 0x24, 0x2e, 0x27, 0x20, 0x22, 0x2c, 0x23, 0x1c, 0x1c, 0x28, 0x37, 0x29, 0x2c, 0x30, 0x31, 0x34, 0x34, 0x34, 0x1f, 0x27, 0x39, 0x3d, 0x38, 0x32, 0x3c, 0x2e, 0x33, 0x34, 0x32, 0xff, 0xdb, 0x0, 0x43, 0x1, 0x9, 0x9, 0x9, 0xc, 0xb, 0xc, 0x18, 0xd, 0xd, 0x18, 0x32, 0x21, 0x1c, 0x21, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0xff, 0xc0, 0x0, 0x11, 0x8, 0x0, 0x10, 0x0, 0x10, 0x3, 0x1, 0x22, 0x0, 0x2, 0x11, 0x1, 0x3, 0x11, 0x1, 0xff, 0xc4, 0x0, 0x1f, 0x0, 0x0, 0x1, 0x5, 0x1, 0x1, 0x1, 0x1, 0x1, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xff, 0xc4, 0x0, 0xb5, 0x10, 0x0, 0x2, 0x1, 0x3, 0x3, 0x2, 0x4, 0x3, 0x5, 0x5, 0x4, 0x4, 0x0, 0x0, 0x1, 0x7d, 0x1, 0x2, 0x3, 0x0, 0x4, 0x11, 0x5, 0x12, 0x21, 0x31, 0x41, 0x6, 0x13, 0x51, 0x61, 0x7, 0x22, 0x71, 0x14, 0x32, 0x81, 0x91, 0xa1, 0x8, 0x23, 0x42, 0xb1, 0xc1, 0x15, 0x52, 0xd1, 0xf0, 0x24, 0x33, 0x62, 0x72, 0x82, 0x9, 0xa, 0x16, 0x17, 0x18, 0x19, 0x1a, 0x25, 0x26, 0x27, 0x28, 0x29, 0x2a, 0x34, 0x35, 0x36, 0x37, 0x38, 0x39, 0x3a, 0x43, 0x44, 0x45, 0x46, 0x47, 0x48, 0x49, 0x4a, 0x53, 0x54, 0x55, 0x56, 0x57, 0x58, 0x59, 0x5a, 0x63, 0x64, 0x65, 0x66, 0x67, 0x68, 0x69, 0x6a, 0x73, 0x74, 0x75, 0x76, 0x77, 0x78, 0x79, 0x7a, 0x83, 0x84, 0x85, 0x86, 0x87, 0x88, 0x89, 0x8a, 0x92, 0x93, 0x94, 0x95, 0x96, 0x97, 0x98, 0x99, 0x9a, 0xa2, 0xa3, 0xa4, 0xa5, 0xa6, 0xa7, 0xa8, 0xa9, 0xaa, 0xb2, 0xb3, 0xb4, 0xb5, 0xb6, 0xb7, 0xb8, 0xb9, 0xba, 0xc2, 0xc3, 0xc4, 0xc5, 0xc6, 0xc7, 0xc8, 0xc9, 0xca, 0xd2, 0xd3, 0xd4, 0xd5, 0xd6, 0xd7, 0xd8, 0xd9, 0xda, 0xe1, 0xe2, 0xe3, 0xe4, 0xe5, 0xe6, 0xe7, 0xe8, 0xe9, 0xea, 0xf1, 0xf2, 0xf3, 0xf4, 0xf5, 0xf6, 0xf7, 0xf8, 0xf9, 0xfa, 0xff, 0xc4, 0x0, 0x1f, 0x1, 0x0, 0x3, 0x1, 0x1, 0x1, 0x1, 0x1, 0x1, 0x1, 0x1, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xff, 0xc4, 0x0, 0xb5, 0x11, 0x0, 0x2, 0x1, 0x2, 0x4, 0x4, 0x3, 0x4, 0x7, 0x5, 0x4, 0x4, 0x0, 0x1, 0x2, 0x77, 0x0, 0x1, 0x2, 0x3, 0x11, 0x4, 0x5, 0x21, 0x31, 0x6, 0x12, 0x41, 0x51, 0x7, 0x61, 0x71, 0x13, 0x22, 0x32, 0x81, 0x8, 0x14, 0x42, 0x91, 0xa1, 0xb1, 0xc1, 0x9, 0x23, 0x33, 0x52, 0xf0, 0x15, 0x62, 0x72, 0xd1, 0xa, 0x16, 0x24, 0x34, 0xe1, 0x25, 0xf1, 0x17, 0x18, 0x19, 0x1a, 0x26, 0x27, 0x28, 0x29, 0x2a, 0x35, 0x36, 0x37, 0x38, 0x39, 0x3a, 0x43, 0x44, 0x45, 0x46, 0x47, 0x48, 0x49, 0x4a, 0x53, 0x54, 0x55, 0x56, 0x57, 0x58, 0x59, 0x5a, 0x63, 0x64, 0x65, 0x66, 0x67, 0x68, 0x69, 0x6a, 0x73, 0x74, 0x75, 0x76, 0x77, 0x78, 0x79, 0x7a, 0x82, 0x83, 0x84, 0x85, 0x86, 0x87, 0x88, 0x89, 0x8a, 0x92, 0x93, 0x94, 0x95, 0x96, 0x97, 0x98, 0x99, 0x9a, 0xa2, 0xa3, 0xa4, 0xa5, 0xa6, 0xa7, 0xa8, 0xa9, 0xaa, 0xb2, 0xb3, 0xb4, 0xb5, 0xb6, 0xb7, 0xb8, 0xb9, 0xba, 0xc2, 0xc3, 0xc4, 0xc5, 0xc6, 0xc7, 0xc8, 0xc9, 0xca, 0xd2, 0xd3, 0xd4, 0xd5, 0xd6, 0xd7, 0xd8, 0xd9, 0xda, 0xe2, 0xe3, 0xe4, 0xe5, 0xe6, 0xe7, 0xe8, 0xe9, 0xea, 0xf2, 0xf3, 0xf4, 0xf5, 0xf6, 0xf7, 0xf8, 0xf9, 0xfa, 0xff, 0xda, 0x0, 0xc, 0x3, 0x1, 0x0, 0x2, 0x11, 0x3, 0x11, 0x0, 0x3f, 0x0, 0xf4, 0x6b, 0xff, 0x0, 0x11, 0xbd, 0xde, 0xbf, 0xa9, 0x58, 0x36, 0xe1, 0x69, 0x64, 0xa5, 0x5d, 0x63, 0x7d, 0xa7, 0x18, 0x4, 0xbb, 0x1e, 0xc0, 0x67, 0x3, 0x3c, 0x71, 0x5c, 0xce, 0x87, 0xe3, 0xd, 0x43, 0x4a, 0xf1, 0xba, 0xe8, 0xd3, 0xc9, 0x34, 0xb6, 0xb2, 0xc9, 0xe5, 0xb4, 0x53, 0x1c, 0x98, 0xcf, 0x62, 0x33, 0xc8, 0xed, 0xc7, 0x4a, 0xed, 0xa6, 0xd1, 0xad, 0x74, 0x9f, 0x12, 0x6a, 0x1a, 0xcb, 0xed, 0x36, 0xfa, 0x8c, 0x2a, 0x93, 0xac, 0xa0, 0x14, 0x57, 0x5e, 0x84, 0xfd, 0x47, 0xaf, 0xa0, 0xac, 0x49, 0xb4, 0xcd, 0x37, 0x5f, 0xf1, 0xe6, 0x9b, 0x71, 0x67, 0x2a, 0x49, 0xf6, 0x48, 0x8c, 0x97, 0x32, 0xc0, 0x3e, 0x46, 0x20, 0xfc, 0x8b, 0x9e, 0xe7, 0xad, 0x5b, 0x50, 0x8b, 0x7c, 0x8f, 0x7b, 0x7e, 0x5a, 0xaf, 0xbf, 0xa9, 0xc5, 0xf5, 0x69, 0xb9, 0xaa, 0x8e, 0x5a, 0xa7, 0xf7, 0xa3, 0xff, 0xd9 }),
                    Color.Magenta, BrowseIconStates.Expanded));
                return list;
            }

            if (iconGuid == NetworkIconGuid)
            {
                list.Add(new BrowseStateIcon(BrowseIcon.ConvertByteToBitmap(
                    new byte[] { 0xff, 0xd8, 0xff, 0xe0, 0x0, 0x10, 0x4a, 0x46, 0x49, 0x46, 0x0, 0x1, 0x1, 0x1, 0x0, 0x60, 0x0, 0x60, 0x0, 0x0, 0xff, 0xdb, 0x0, 0x43, 0x0, 0x8, 0x6, 0x6, 0x7, 0x6, 0x5, 0x8, 0x7, 0x7, 0x7, 0x9, 0x9, 0x8, 0xa, 0xc, 0x14, 0xd, 0xc, 0xb, 0xb, 0xc, 0x19, 0x12, 0x13, 0xf, 0x14, 0x1d, 0x1a, 0x1f, 0x1e, 0x1d, 0x1a, 0x1c, 0x1c, 0x20, 0x24, 0x2e, 0x27, 0x20, 0x22, 0x2c, 0x23, 0x1c, 0x1c, 0x28, 0x37, 0x29, 0x2c, 0x30, 0x31, 0x34, 0x34, 0x34, 0x1f, 0x27, 0x39, 0x3d, 0x38, 0x32, 0x3c, 0x2e, 0x33, 0x34, 0x32, 0xff, 0xdb, 0x0, 0x43, 0x1, 0x9, 0x9, 0x9, 0xc, 0xb, 0xc, 0x18, 0xd, 0xd, 0x18, 0x32, 0x21, 0x1c, 0x21, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0x32, 0xff, 0xc0, 0x0, 0x11, 0x8, 0x0, 0x10, 0x0, 0x10, 0x3, 0x1, 0x22, 0x0, 0x2, 0x11, 0x1, 0x3, 0x11, 0x1, 0xff, 0xc4, 0x0, 0x1f, 0x0, 0x0, 0x1, 0x5, 0x1, 0x1, 0x1, 0x1, 0x1, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xff, 0xc4, 0x0, 0xb5, 0x10, 0x0, 0x2, 0x1, 0x3, 0x3, 0x2, 0x4, 0x3, 0x5, 0x5, 0x4, 0x4, 0x0, 0x0, 0x1, 0x7d, 0x1, 0x2, 0x3, 0x0, 0x4, 0x11, 0x5, 0x12, 0x21, 0x31, 0x41, 0x6, 0x13, 0x51, 0x61, 0x7, 0x22, 0x71, 0x14, 0x32, 0x81, 0x91, 0xa1, 0x8, 0x23, 0x42, 0xb1, 0xc1, 0x15, 0x52, 0xd1, 0xf0, 0x24, 0x33, 0x62, 0x72, 0x82, 0x9, 0xa, 0x16, 0x17, 0x18, 0x19, 0x1a, 0x25, 0x26, 0x27, 0x28, 0x29, 0x2a, 0x34, 0x35, 0x36, 0x37, 0x38, 0x39, 0x3a, 0x43, 0x44, 0x45, 0x46, 0x47, 0x48, 0x49, 0x4a, 0x53, 0x54, 0x55, 0x56, 0x57, 0x58, 0x59, 0x5a, 0x63, 0x64, 0x65, 0x66, 0x67, 0x68, 0x69, 0x6a, 0x73, 0x74, 0x75, 0x76, 0x77, 0x78, 0x79, 0x7a, 0x83, 0x84, 0x85, 0x86, 0x87, 0x88, 0x89, 0x8a, 0x92, 0x93, 0x94, 0x95, 0x96, 0x97, 0x98, 0x99, 0x9a, 0xa2, 0xa3, 0xa4, 0xa5, 0xa6, 0xa7, 0xa8, 0xa9, 0xaa, 0xb2, 0xb3, 0xb4, 0xb5, 0xb6, 0xb7, 0xb8, 0xb9, 0xba, 0xc2, 0xc3, 0xc4, 0xc5, 0xc6, 0xc7, 0xc8, 0xc9, 0xca, 0xd2, 0xd3, 0xd4, 0xd5, 0xd6, 0xd7, 0xd8, 0xd9, 0xda, 0xe1, 0xe2, 0xe3, 0xe4, 0xe5, 0xe6, 0xe7, 0xe8, 0xe9, 0xea, 0xf1, 0xf2, 0xf3, 0xf4, 0xf5, 0xf6, 0xf7, 0xf8, 0xf9, 0xfa, 0xff, 0xc4, 0x0, 0x1f, 0x1, 0x0, 0x3, 0x1, 0x1, 0x1, 0x1, 0x1, 0x1, 0x1, 0x1, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xff, 0xc4, 0x0, 0xb5, 0x11, 0x0, 0x2, 0x1, 0x2, 0x4, 0x4, 0x3, 0x4, 0x7, 0x5, 0x4, 0x4, 0x0, 0x1, 0x2, 0x77, 0x0, 0x1, 0x2, 0x3, 0x11, 0x4, 0x5, 0x21, 0x31, 0x6, 0x12, 0x41, 0x51, 0x7, 0x61, 0x71, 0x13, 0x22, 0x32, 0x81, 0x8, 0x14, 0x42, 0x91, 0xa1, 0xb1, 0xc1, 0x9, 0x23, 0x33, 0x52, 0xf0, 0x15, 0x62, 0x72, 0xd1, 0xa, 0x16, 0x24, 0x34, 0xe1, 0x25, 0xf1, 0x17, 0x18, 0x19, 0x1a, 0x26, 0x27, 0x28, 0x29, 0x2a, 0x35, 0x36, 0x37, 0x38, 0x39, 0x3a, 0x43, 0x44, 0x45, 0x46, 0x47, 0x48, 0x49, 0x4a, 0x53, 0x54, 0x55, 0x56, 0x57, 0x58, 0x59, 0x5a, 0x63, 0x64, 0x65, 0x66, 0x67, 0x68, 0x69, 0x6a, 0x73, 0x74, 0x75, 0x76, 0x77, 0x78, 0x79, 0x7a, 0x82, 0x83, 0x84, 0x85, 0x86, 0x87, 0x88, 0x89, 0x8a, 0x92, 0x93, 0x94, 0x95, 0x96, 0x97, 0x98, 0x99, 0x9a, 0xa2, 0xa3, 0xa4, 0xa5, 0xa6, 0xa7, 0xa8, 0xa9, 0xaa, 0xb2, 0xb3, 0xb4, 0xb5, 0xb6, 0xb7, 0xb8, 0xb9, 0xba, 0xc2, 0xc3, 0xc4, 0xc5, 0xc6, 0xc7, 0xc8, 0xc9, 0xca, 0xd2, 0xd3, 0xd4, 0xd5, 0xd6, 0xd7, 0xd8, 0xd9, 0xda, 0xe2, 0xe3, 0xe4, 0xe5, 0xe6, 0xe7, 0xe8, 0xe9, 0xea, 0xf2, 0xf3, 0xf4, 0xf5, 0xf6, 0xf7, 0xf8, 0xf9, 0xfa, 0xff, 0xda, 0x0, 0xc, 0x3, 0x1, 0x0, 0x2, 0x11, 0x3, 0x11, 0x0, 0x3f, 0x0, 0xf4, 0x6b, 0xff, 0x0, 0x11, 0xbd, 0xde, 0xbf, 0xa9, 0x58, 0x36, 0xe1, 0x69, 0x64, 0xa5, 0x5d, 0x63, 0x7d, 0xa7, 0x18, 0x4, 0xbb, 0x1e, 0xc0, 0x67, 0x3, 0x3c, 0x71, 0x5c, 0xce, 0x87, 0xe3, 0xd, 0x43, 0x4a, 0xf1, 0xba, 0xe8, 0xd3, 0xc9, 0x34, 0xb6, 0xb2, 0xc9, 0xe5, 0xb4, 0x53, 0x1c, 0x98, 0xcf, 0x62, 0x33, 0xc8, 0xed, 0xc7, 0x4a, 0xed, 0xa6, 0xd1, 0xad, 0x74, 0x9f, 0x12, 0x6a, 0x1a, 0xcb, 0xed, 0x36, 0xfa, 0x8c, 0x2a, 0x93, 0xac, 0xa0, 0x14, 0x57, 0x5e, 0x84, 0xfd, 0x47, 0xaf, 0xa0, 0xac, 0x49, 0xb4, 0xcd, 0x37, 0x5f, 0xf1, 0xe6, 0x9b, 0x71, 0x67, 0x2a, 0x49, 0xf6, 0x48, 0x8c, 0x97, 0x32, 0xc0, 0x3e, 0x46, 0x20, 0xfc, 0x8b, 0x9e, 0xe7, 0xad, 0x5b, 0x50, 0x8b, 0x7c, 0x8f, 0x7b, 0x7e, 0x5a, 0xaf, 0xbf, 0xa9, 0xc5, 0xf5, 0x69, 0xb9, 0xaa, 0x8e, 0x5a, 0xa7, 0xf7, 0xa3, 0xff, 0xd9 }),
                //                    Color.Magenta, BrowseIconStates.None));
                Color.Black, BrowseIconStates.None)
                { Scalable = false, SurroundedColor = Color.Red, BorderThickness = 2, BorderColor = Color.Green });
                return list;
            }

            if (iconGuid == WorkGroupIconGuid)
            {
                list.Add(new BrowseStateIcon(BaseLibFormsTestAppResource.Places_folder_orange));
                //                list.Add(new BrowseStateIcon(BaseLibFormsTestAppResource.Places_folder_orange, Color.FromArgb(0, 0, 0), BrowseIconStates.None));
                //                return BrowseStateIcon.GetImagesFromIcon(BaseLibFormsTestAppResource.Places_folder_orange, BrowseIconStates.Default, BrowseStateIcon.ImageSize.LargeAndSmall, Color.Green);
                //                return BrowseStateIcon.GetImagesFromIcon(BaseLibFormsTestAppResource.Places_folder_orange, BrowseIconStates.Default);
                //                list.AddRange(BrowseStateIcon.GetImagesFromIcon(BaseLibFormsTestAppResource.Chat_orange, BrowseIconStates.Default));
                return list;
            }

            return Enumerable.Empty<BrowseStateIcon>();
        }

        public BrowseColumnParameters GetColumnParameters(Guid columnGuid)
        {
            // ReSharper disable LocalizableElement
            if (columnGuid == TypeColumnGuid) return new BrowseColumnParameters("Type", 50) { Alignment = HorizontalAlignment.Right };
            // ReSharper restore LocalizableElement
            return null;
        }

        public IEnumerable<Guid> GetColumnsForParent(Object parentNode)
        {
            Always.RequiresNotNull(parentNode, nameof(parentNode));
            Check.EnsuresResultNotNull<IEnumerable<Guid>>();

            return Enumerable.Empty<Guid>();
        }

        public string GetContent(Object node, Guid columnGuid)
        {
            Always.RequiresNotNull(node, nameof(node));

            if (columnGuid == TypeColumnGuid) return node.GetType().ToString() + " " + DateTime.Now.ToShortTimeString();
            if ((columnGuid == ColumnGuids.Tooltip) && (node.GetType().Name != "WorkGroup")) return node.GetType().ToString();
            return DefaultNodePresentation.Instance.GetContent(node, columnGuid);
        }

        public IEnumerable<ToolStripItem> GetContextMenuItems(IEnumerable<object> nodePath, bool isManual, BrowseNodesFormViews view, IBrowsePresentationHost browsePresentationHost)
        {
            // ReSharper disable once PossibleMultipleEnumeration
            Always.RequiresAllNotNull(nodePath, nameof(nodePath));
            Always.RequiresNotNull(browsePresentationHost, nameof(browsePresentationHost));
            Check.EnsuresResultNotNull<IEnumerable<ToolStripItem>>();

            var node = nodePath.LastOrDefault();
            if (node != null)
            {
                if (node.ToString() == "2")
                {
                    return new ToolStripItem[]
                    {new ToolStripMenuItem("Item1 - node 2"), new ToolStripMenuItem("Item2 - node 2")};
                }
                if (node.ToString() == "6")
                {
                    var testMenuItem = new ToolStripMenuItem(
                    "Item 6 test Refresh",
                    null,
                    (sender, args) => browsePresentationHost.RefreshNode(nodePath, true));

                    var newNode = new Folder("6x");
                    var newNodePath = nodePath.ToList();
                    newNodePath.RemoveAt(newNodePath.Count - 1);
                    newNodePath.Add(newNode);
                    var testMenuItem2 = new ToolStripMenuItem(
                    "Item 6 test Add",
                    null,
                    (sender, args) => browsePresentationHost.AddManualNode(newNodePath, false));

                    var newNodeW = new WorkGroup("6w");
                    var newNodePathW = nodePath.ToList();
                    newNodePathW.Add(newNodeW);
                    var testMenuItem3 = new ToolStripMenuItem(
                    "Item 6 test Add child",
                    null,
                    (sender, args) => browsePresentationHost.AddManualNode(newNodePathW, false));

                    var newNodeS = "6s";
                    var newNodePathS = newNodePathW.ToList();
                    newNodePathS.Add(newNodeS);
                    var testMenuItem4 = new ToolStripMenuItem(
                    "Item 6 test Add child child",
                    null,
                    (sender, args) => browsePresentationHost.AddManualNode(newNodePathS, false));

                    return new ToolStripItem[] { testMenuItem, testMenuItem2, testMenuItem3, testMenuItem4 };

                }
                var items = new List<ToolStripItem>();
                if (isManual)
                {
                    var menuItem = new ToolStripMenuItem("Delete Manual") {ShortcutKeys = Keys.F8};
                    menuItem.Click += (sender, e) => { browsePresentationHost.DeleteManualNode(nodePath); };
                    items.Add(menuItem);
                }


                var menuItem6 = new ToolStripMenuItem("Is manual");
                menuItem6.Click += (sender, e) => { MessageBox.Show("Is manual: " + browsePresentationHost.IsNodeManual(nodePath)); };
                items.Add(menuItem6);

                if ((view & BrowseNodesFormViews.List) == BrowseNodesFormViews.List)
                {
                    var menuItem8 = new ToolStripMenuItem("Only in list view");
                    menuItem8.Click += (sender, e) => { MessageBox.Show("Is in list view."); };
                    items.Add(menuItem8);
                }
                return items.ToArray();
            }
            return Enumerable.Empty<ToolStripItem>();
        }

        public string GetCreateNodeNameHint(object parentNode, Type type)
        {
            Always.RequiresNotNull(parentNode, nameof(parentNode));
            Always.RequiresNotNull(type, nameof(type));

            return ("Enter name for <" + type.Name + "> node. Long 1 long 2 long 3 long 4 long 5 long 6 long 7 long 8 long 8 long 9 long 10 long 11.");

//            return null;
        }



        public bool GetDataObject(IEnumerable<IEnumerable<object>> nodePaths, BrowseNodesFormViews view, out IDataObject dataObject)
        {
            Always.RequiresNotNull(nodePaths, nameof(nodePaths));

            object node = nodePaths.LastOrDefault()?.LastOrDefault();
            if (node != null)
            {
                if (node.GetType().Name == "Network")
                {
                    dataObject = null;
                    return true; // drag and drop functionality is disabled for network
                }
            }
            return DefaultNodePresentation.Instance.GetDataObject(nodePaths, view, out dataObject);
        }


        public Object GetDefaultBranchFilter(Object parentNode)
        {
            Always.RequiresNotNull(parentNode, nameof(parentNode));

            Type type = parentNode.GetType();
            if (type.Name == "Network") return new FolderFilter("*");
            return null;
        }

        public Object GetDefaultLeafFilter(Object parentNode)
        {
            Always.RequiresNotNull(parentNode, nameof(parentNode));

            Type type = parentNode.GetType();
            if (type.Name == "Network") return new FolderFilter("*");
            return null;
        }

        public string GetDisplayName(IEnumerable<object> nodePath, BrowseNodesFormViews view)
        {
            Always.RequiresNotNull(nodePath, nameof(nodePath));
            IEnumerable<object> enumeratedNodePath = nodePath as IList<object> ?? nodePath.ToList();
            Always.Requires(Check.ForAll(enumeratedNodePath, o => o != null));

            object node = enumeratedNodePath.LastOrDefault();
            if (node != null)
            {
                if (node.ToString() == "L2") return null;
                if (node.ToString() == "First") return null;
                if (node.ToString() == "L3") return "L3 name";
            }
            return DefaultNodePresentation.Instance.GetDisplayName(enumeratedNodePath, view);
        }

        public bool GetIconGuidLegend(Guid iconGuid, out string category, out string displayName, out string description)
        {
            if (iconGuid == FolderIconGuid)
            {
                category = "File System";
                displayName = "Folder";
                description = "Folder is ...";
                return true;
            }
            if (iconGuid == NetworkIconGuid)
            {
                category = "Network";
                displayName = "Network";
                description = "Netowrk is ...";
                return true;
            }
            if (iconGuid == WorkGroupIconGuid)
            {
                category = "Network";
                displayName = "Work Group";
                description = "Work group is ...";
                return true;
            }
            return DefaultNodePresentation.Instance.GetIconGuidLegend(iconGuid, out category, out displayName, out description);
        }

        public bool GetTextForEditing(IEnumerable<object> parentNodePath, object node, Type type,
            BrowseNodesFormViews view, ref string text, ref int selectionStart, ref int selectionLength, ref Font font)
        {
            Always.RequiresNotNull(parentNodePath, nameof(parentNodePath));
            IEnumerable<object> enumeratedParentNodePath = parentNodePath as IList<object> ?? parentNodePath.ToList();
            Always.Requires(Check.ForAll(enumeratedParentNodePath, o => o != null));
            Always.RequiresNotNull(type, nameof(type));

            if (node != null)
            {
                if (node.ToString() == "L3")
                {
                    text = "L3 edit";
                    selectionStart = 3;
                    font = new Font(FontFamily.GenericMonospace, 48);
                    return true;
                }
            }

            return DefaultNodePresentation.Instance.GetTextForEditing(enumeratedParentNodePath, node, type, view, ref text, ref selectionStart, ref selectionLength, ref font);
        }

        public string GetTypeName(Type type)
        {
            Always.RequiresNotNull(type, nameof(type));
            return DefaultNodePresentation.Instance.GetTypeName(type);
        }

        public string GetInfoText(Object node)
        {
            Always.RequiresNotNull(node, nameof(node));

            if (node is WorkGroup)
            {
                var r = new RichTextBox();
                r.SelectionStart = r.TextLength;
                r.SelectionColor = Color.Red;
                r.SelectedText = "Workgroup: \t";
                r.SelectionStart = r.TextLength;
                r.SelectionColor = Color.Blue;
                r.SelectionFont = new Font("Arial", 14, FontStyle.Bold);
                r.SelectionBackColor = Color.Magenta;
                r.SelectionBullet = true;
                r.SelectedText = node + " www.opclabs.com \n";
                r.AppendText("ěščřžýáíé http:\\\\www.weblink.out");
                return r.Rtf;

            }

            if (node == null) throw new ArgumentNullException(nameof(node));

            if (node.ToString() == "LB")
            {
                string textToolTip = null;
                using (var richTextBuilder = new RichTextBuilder())
                {
                    richTextBuilder
                        //                    .SetStyle(presentationScheme.TextStyle)
                        .AppendTextLine("RTF ToolTip")
                        .AppendCopyableTextLine("copyable text")
                        .AppendTextLine("line")
                        .AppendText("sample: ")
                        .AppendCommand(RichTextBoxCommand.ToolTip, "remarks long long long long long", null)
                        .AppendText("text with toolTIip")
                        .AppendCommand(RichTextBoxCommand.ToolTipEnd, null, null)
                        .AppendTextLine(" text without toolTip")
                        .AppendTextLine("Last line");

                    textToolTip = richTextBuilder.ToString();
                }

                string text = null;
                using (var richTextBuilder = new RichTextBuilder())
                {
                    richTextBuilder
                        //                    .SetStyle(presentationScheme.TextStyle)
                        .AppendTextLine("First line")
                        .AppendCopyableTextLine("copyable text")
                        .AppendTextLine("line")
                        .AppendText("sample: ")
                        .AppendCommand(RichTextBoxCommand.ToolTip, "remarks long long long long long", null)
                        .AppendText("text with toolTIip")
                        .AppendCommand(RichTextBoxCommand.ToolTipEnd, null, null)
                        .AppendTextLine(" text without toolTip")
                        .AppendTextLine("line")
                        .AppendTextLine("line")
                        .AppendText("sample2: ")
                        .AppendCommand(RichTextBoxCommand.ToolTip, textToolTip, null)
                        .AppendText("text with enhancedToolTIip")
                        .AppendCommand(RichTextBoxCommand.ToolTipEnd, null, null)
                        .AppendTextLine(" text without toolTip")
                        .AppendTextLine("Last line");

                    text = richTextBuilder.ToString();
                    return text;
                }

            }

            return "Node: " + GetDisplayName(new object[] { node }, BrowseNodesFormViews.None) + "\nType: " + GetTypeName(node.GetType());

            //            return DefaultBrowsePresentation.Instance.GetInfoText(node);
        }

        public IEnumerable<Guid?> GetNodeIconGuids(object node)
        {
            Always.RequiresNotNull(node, nameof(node));
            Check.EnsuresResultNotNull<IEnumerable<Guid?>>();

            return Enumerable.Empty<Guid?>();
        }

        public IEnumerable<Guid> GetTypeColumns(Type type)
        {
            Always.RequiresNotNull(type, nameof(type));
            Check.Ensures(Check.Result<IEnumerable<Guid>>() != null);

            if (type.Name == "Network") return new List<Guid> { TypeColumnGuid };

            return Enumerable.Empty<Guid>();
        }

        public IEnumerable<Guid> GetTypeIconGuids(Type type)
        {
            Always.RequiresNotNull(type, nameof(type));
            Check.EnsuresResultNotNull<IEnumerable<Guid>>();

            if (type.Name == "Folder") return new[] { FolderIconGuid, WorkGroupIconGuid, NetworkIconGuid };
            if (type.Name == "Network") return new[] { NetworkIconGuid };
            if (type.Name == "WorkGroup") return new[] { WorkGroupIconGuid };
            return Enumerable.Empty<Guid>();
        }

        public bool ModifyNodeStyle(object node, BrowseIconStates nodeStates, BrowseNodeStyle nodeStyle)
        {
            Always.RequiresNotNull(node, nameof(node));
            Always.RequiresNotNull(nodeStyle, nameof(nodeStyle));

            // body changed by ZbynekZ:
            // DefaultBrowsePresentation.Instance.ModifyNodeStyle(node, nodeStates, nodeStyle);
            if (node is string)
            {
                nodeStyle.BackColor = Color.Red;
                return true;
            }
            if (node is WorkGroup)
            {
                nodeStyle.Color = Color.Red;
                return true;
            }
            if (node is Network)
            {
                nodeStyle.Color = Color.Blue;
                return true;
            }
            return false;
        }

        public void NodeCreated(object node)
        {
            Always.RequiresNotNull(node, nameof(node));
            // Do nothing.
        }

        public void NodeEdited(object node, object oldNode)
        {
            Always.RequiresNotNull(node, nameof(node));
            Always.RequiresNotNull(oldNode, nameof(oldNode));
            // Do nothing.
        }

        [System.Diagnostics.CodeAnalysis.SuppressMessage("Microsoft.Design", "CA1062:ValidateArgumentsOfPublicMethods")]    // using CC runtime check on interface
        public bool ShouldAutoExpand(IEnumerable<object> nodePath)
        {
            Always.RequiresNotNull(nodePath, nameof(nodePath));
            IEnumerable<object> enumeratedNodePath = nodePath as IList<object> ?? nodePath.ToList();
            Always.Requires(Check.ForAll(enumeratedNodePath, o => o != null));

            object node = enumeratedNodePath.LastOrDefault();
            if (node != null)
            {
                if (node.ToString() == "1a") return true;
            }

            return DefaultNodePresentation.Instance.ShouldAutoExpand(enumeratedNodePath);
        }

        #endregion
    }

    class BrowsePresentationTestSample : IBrowsePresentation
    {
        public IEnumerable<Guid> GetStaticColumns()
        {
            Check.EnsuresResultNotNull<IEnumerable<Guid>>();
            return Enumerable.Empty<Guid>();
        }

        public string GetText(BrowseNodesTextId id)
        {
            /*
            switch (id)
            {
                //case BrowseNodesForm.TextId.NodesListViewLabelFormat: return "Current node: {0}\nContent:";
                //case BrowseNodesForm.TextId.NodeIdentificationLabelFormat: return "Selected node: {0}\nNode Identification:";
            }
             * */
            return null;
        }

        public IEnumerable<ToolStripItem> GetToolMenuItems(IBrowsePresentationHost browsePresentationHost, BrowseNodesFormViews view)
        {
            Always.RequiresNotNull(browsePresentationHost, nameof(browsePresentationHost));
            Check.EnsuresResultNotNull<IEnumerable<ToolStripItem>>();

            var items = new List<ToolStripItem>();

            switch (view)
            {
                case BrowseNodesFormViews.ActionsPane:
                    break;
                case BrowseNodesFormViews.ActionsPane | BrowseNodesFormViews.Tree:
                case BrowseNodesFormViews.ActionsPane | BrowseNodesFormViews.List:
                case BrowseNodesFormViews.ActionsPane | BrowseNodesFormViews.Selected:
                    // global items for actions panel
                    // view can be also Tree, List, Selected (means control in which is focused node)
                    var toolStripLabel = new ToolStripLabel("Global commands:");
                    items.Add(toolStripLabel);
                    var toolStripMenuItem = new ToolStripMenuItem("Global command1");
                    toolStripMenuItem.DropDownItems.Add(new ToolStripMenuItem("sub1"));
                    items.Add(toolStripMenuItem);
                    break;
                case BrowseNodesFormViews.ActionsPane | BrowseNodesFormViews.ContextMenu:
                    break;
            }
            return items;

            /*
            if ((view & BrowseNodesFormViews.ContextMenu) == BrowseNodesFormViews.ContextMenu) // must be first
            {
                // items for all context menu
                var toolStripButton = new ToolStripButton("Global Context Func");
                items.Add(toolStripButton);
                if ((view & BrowseNodesFormViews.ToolStrip) == BrowseNodesFormViews.ToolStrip)
                {
                    // items for tool strip context menu
                    var toolStripMenuItem = new ToolStripMenuItem("Global context menu for tool strip");
                    items.Add(toolStripMenuItem);
                }
                else
                {
                    if ((view & BrowseNodesFormViews.StatusStrip) == BrowseNodesFormViews.StatusStrip)
                    {
                        // items for tool strip context menu
                        var toolStripMenuItem = new ToolStripMenuItem("Global context menu for status strip");
                        items.Add(toolStripMenuItem);
                    }

                    else
                    {
                        if ((view & BrowseNodesFormViews.ActionsPane) == BrowseNodesFormViews.ActionsPane)
                        {
                            // items for commands panel context menu
                            var toolStripMenuItem = new ToolStripMenuItem("Global context menu for commands panel");
                            items.Add(toolStripMenuItem);
                        }
                        else
                        {
                            // items for all context menu except tool strip context menu, status strip context menu and commands panel context menu

                            // view can be also Tree, List, Selected or None (for context menu of another parts)
                        }
                    }
                }
            }
            else
            {
                if ((view & BrowseNodesFormViews.ToolStrip) == BrowseNodesFormViews.ToolStrip)
                {
                    // global items for tool strip - item type must be for tool strip
                    var toolStripButton = new ToolStripButton("Global Func");
                    toolStripButton.Click += (s, e) => 
                    {
                        var currentPath = browsePresentationHost.CurrentPath;
                        var traverser = browsePresentationHost.GetTreeTraversable();


                        var root = traverser.GetTreeTraverser();
                        };
                    items.Add(toolStripButton);
                }
                else
                {
                    if ((view & BrowseNodesFormViews.ToolsMenu) == BrowseNodesFormViews.ToolsMenu)
                    {
                        // global items for tools menu
                        // view can be also Tree, List, Selected (means control in which is focused node)
                        var toolStripMenuItem = new ToolStripMenuItem("Global tool1");
                        items.Add(toolStripMenuItem);
                        items.Add(new ToolStripSeparator());
                    }
                    else
                    {
                        if ((view & BrowseNodesFormViews.ActionsPane) == BrowseNodesFormViews.ActionsPane)
                        {
                            // global items for commands panel
                            // view can be also Tree, List, Selected (means control in which is focused node)
                            var toolStripLabel = new ToolStripLabel("Global commands:");
                            items.Add(toolStripLabel);
                            var toolStripMenuItem = new ToolStripMenuItem("Global command1");
                            toolStripMenuItem.DropDownItems.Add(new ToolStripMenuItem("sub1"));
                            items.Add(toolStripMenuItem);
                        }
                    }
                }
            }
            
            return items;
            */
        }


        public IEnumerable<Rectangle> GetIconLayout(BrowseNodesFormView view, BrowseImageSize imageSize)
        {
            Check.EnsuresResultNotNull<IEnumerable<Rectangle>>();

            if ((view == BrowseNodesFormView.Tree))
                return new[] { new Rectangle(0, 0, 16, 16), new Rectangle(17, 0, 8, 16) };
            if ((view == BrowseNodesFormView.List) && (imageSize == BrowseImageSize.Small))
                return new[] { new Rectangle(0, 0, 16, 16), new Rectangle(17, 0, 16, 16), new Rectangle(9, 0, 16, 16) };
//            return new[] { new Rectangle(0, 0, 16, 16), new Rectangle(17, 0, 16, 16), new Rectangle(33, 0, 16, 16) };
            if ((view == BrowseNodesFormView.List) && (imageSize == BrowseImageSize.Large))
                return new[] { new Rectangle(0, 0, 32, 32), new Rectangle(33, 0, 16, 16), new Rectangle(33, 16, 16, 16) };
            if ((view == BrowseNodesFormView.ToolsMenu) && (imageSize == BrowseImageSize.Small))
                return new[] { new Rectangle(0, 0, 16, 16), new Rectangle(17, 0, 16, 16), new Rectangle(9, 0, 16, 16) };
            return Enumerable.Empty<Rectangle>();
        }


        public IEnumerable<BrowseStateIcon> GetDefaultIcons()
        {
            Check.EnsuresResultNotNull<IEnumerable<BrowseStateIcon>>();
            Check.Ensures(Check.ForAll(Check.Result<IEnumerable<BrowseStateIcon>>(), browseIcon => browseIcon != null));

            return DefaultBrowsePresentation.Instance.GetDefaultIcons();
        }



        public BrowseColumnParameters GetDisplayNameColumnParameters(BrowseNodesFormViews view)
        {
// ReSharper disable LocalizableElement
            if (view == BrowseNodesFormViews.List) return new BrowseColumnParameters { HeaderText = "Name", DefaultWidth = 100 };
// ReSharper restore LocalizableElement
            return DefaultBrowsePresentation.Instance.GetDisplayNameColumnParameters(view);
        }

        public string GetExceptionText(Exception exception)
        {
            Always.RequiresNotNull(exception, nameof(exception));
            Check.EnsuresResultNotNull<string>();

            return DefaultBrowsePresentation.Instance.GetExceptionText(exception);
        }

        public BrowseIcon GetIcon(BrowseNodesFormIcon iconId)
        {
            return DefaultBrowsePresentation.Instance.GetIcon(iconId);
        }

        public void AppendText(string text, Color foreColor, Color backColor, string fontFamily = null, int fontSize = -1, FontStyle setStyle = FontStyle.Regular, FontStyle resetStyle = FontStyle.Regular, bool? showBullet = null, int[] tabs = null)
        {
        }






        public BrowseNodesPresentationOptions GetPresentationOptions()
        {
            Check.EnsuresResultNotNull<BrowseNodesPresentationOptions>();
            return new BrowseNodesPresentationOptions();
        }

        // only for sample
        //public void SetFormOptions(BrowseNodesFormOptions formOptions)
        //{
        //    _formOptions = formOptions;
        //}

/*
        static Guid _folderColumn1Guid = Guid.NewGuid();
*/
/*
        static Guid _networkColumn1Guid = Guid.NewGuid();
*/

    }
}
