﻿using System;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using OpcLabs.BaseLib;
using OpcLabs.BaseLib.ComponentModel.Linking;
using OpcLabs.EasyOpc.DataAccess.LiveMapping;
using OpcLabs.UnitTestLib;

namespace OpcLabs.EasyOpcLiveTest.Legacy.LiveMapping._Testers
{
    class EventTester
    {
        [DAType, DASubscription(RequestedUpdateRate = 100)]
        private class EventTestType
        {
#pragma warning disable 67
            [DANode(ItemId = LegacyTestDefs.DataAccess.ItemIds.Incrementing_1s), DAItem(ItemType = typeof(Int32))]
            public event DataEventHandler<Int32> IncrementingEvent;
#pragma warning restore 67
        }

        public void Test()
        {
            const int timeout = 10*1000;
            const int period = 1000;

            int count = 0;

            // ReSharper disable LocalizableElement
            var clientMapper = new DAClientMapper();
            var testTarget = new EventTestType();
            // ReSharper disable PossibleNullReferenceException
            testTarget.IncrementingEvent += ((_, args) => Console.WriteLine("First handler: {0}", args.Data));
            testTarget.IncrementingEvent += ((_, args) => Console.WriteLine("Second handler: {0}", args.Data));
            testTarget.IncrementingEvent += ((_, args) => count++);
            // ReSharper restore PossibleNullReferenceException

            clientMapper.Map(testTarget, new DAMappingContext { ServerDescriptor = LegacyTestDefs.ProgIds.KitServer });

            clientMapper.Subscribe(true);
            AssertUtilities.WaitingPhase(timeout);
            clientMapper.Subscribe(false);
            // ReSharper restore LocalizableElement

            Assert.IsTrue(count >= timeout/period/2);
        }
    }
}
