﻿using System;
using JetBrains.Annotations;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using OpcLabs.EasyOpc.UA;
using OpcLabs.EasyOpc.UA.Generic;
using OpcLabs.EasyOpc.UA.LiveMapping;
using OpcLabs.EasyOpcLiveTest.UA.Environment;
using OpcLabs.UnitTestLib;

namespace OpcLabs.EasyOpcLiveTest.UA.LiveMapping
{
    class NodeIdTester
    {
        private class TestRecord
        {
            public int ValueCount { get; set; }
            public int AttributeDataCount { get; set; }
            public int StatusCount { get; set; }
            public int ResultCount { get; set; }
        }

        [UAType, UAMonitoring(SamplingInterval = 100)]
        private class NodeIdTestType
        {
            public NodeIdTestType([NotNull] TestRecord testRecord)
            {
                TestRecord = testRecord;
            }

            [UANode(NodeId = OpcFoundation_UASampleServer.NodeIdExpandedTexts.Data_Dynamic_UserScalar_Int32Value), UAData]
            public Int32 Value
            {
                set
                {
                    TestRecord.ValueCount++;
                    AssertUtilities.WriteLine($"Value: {value}");
                }
            }

            [UANode(NodeId = OpcFoundation_UASampleServer.NodeIdExpandedTexts.Data_Dynamic_UserScalar_Int32Value), UAData(ValueType = typeof(Int32), Kind = UADataMappingKind.AttributeData)]
            public UAAttributeData<Int32> AttributeData
            {
                set
                {
                    TestRecord.AttributeDataCount++;
                    AssertUtilities.WriteLine($"AttributeData: {value}");
                }
            }

            [UANode(NodeId = OpcFoundation_UASampleServer.NodeIdExpandedTexts.Data_Dynamic_UserScalar_Int32Value), UAData(Kind = UADataMappingKind.StatusCode)]
            public UAStatusCode StatusCode
            {
                set
                {
                    TestRecord.StatusCount++;
                    AssertUtilities.WriteLine($"Quality: {value}");
                }
            }

            [UANode(NodeId = OpcFoundation_UASampleServer.NodeIdExpandedTexts.Data_Dynamic_UserScalar_Int32Value), UAData(ValueType = typeof(Int32), Kind = UADataMappingKind.Result)]
            public UAAttributeDataResult<Int32> Result
            {
                set
                {
                    TestRecord.ResultCount++;
                    Assert.IsNotNull(value);
                    AssertUtilities.WriteLine($"Result.AttributeData: {value.TypedAttributeData}");
                }
            }

            [NotNull]
            // ReSharper disable MemberCanBePrivate.Local
            public TestRecord TestRecord { get; }
            // ReSharper restore MemberCanBePrivate.Local
        }

        public void Test()
        {
            const int timeout = 10 * 1000;
            const int period = 1000;

            TestSection.Arrange();

            UAEndpointDescriptor endpointDescriptor = UATestEnvironment.OpcFoundation_UASampleServer.EndpointDescriptors.OpcTcp;
            TestEnvironment.PrecheckEndpoint(endpointDescriptor);

            var testRecord = new TestRecord();

            var mapper = new UAClientMapper();
            var testTarget = new NodeIdTestType(testRecord);

            mapper.Map(testTarget, new UAMappingContext { EndpointDescriptor = endpointDescriptor });

            TestSection.Act();

            mapper.Subscribe(true);
            AssertUtilities.WaitingPhase(timeout);
            mapper.Subscribe(false);

            TestSection.Assert();

            const int minimumCount = timeout/period/2;
            Assert.IsTrue(testRecord.ValueCount >= minimumCount);
            Assert.IsTrue(testRecord.AttributeDataCount >= minimumCount);
            Assert.IsTrue(testRecord.StatusCount >= minimumCount);
            Assert.IsTrue(testRecord.ResultCount >= minimumCount);
        }

        [NotNull]
        private UATestEnvironment TestEnvironment => UATestEnvironment.Current;
    }
}
