﻿
using JetBrains.Annotations;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using OpcLabs.BaseLib.DataTypeModel;
using OpcLabs.EasyOpc.UA.DataTypeModel;
using OpcLabs.EasyOpc.UA.DataTypeModel.Implementation;

namespace OpcLabs.EasyOpcTest.UA.DataTypeModel.Internal
{
    partial class DeveloperTest
    {
        #region Static Private Properties

        [NotNull]
        static private StructuredDataType IntegerArrayWithVariableLengthInBytesDataType => new StructuredDataType("IntegerArrayWithVariableLengthInBytes", "DeveloperTest:IntegerArrayWithVariableLengthInBytes")
        {
            new DataField("Size", UAOpcBinaryStandardDataTypes.Int32) { IsLength = true },
            new DataField("Array", new SequenceDataType(UAOpcBinaryStandardDataTypes.Int32)){ IsOptional = true }
        };

        [NotNull]
        static private StructuredData IntegerArrayWithVariableLengthInBytes_0Data => new StructuredData(IntegerArrayWithVariableLengthInBytesDataType)
        {
            { "Size", new PrimitiveData(UAOpcBinaryStandardDataTypes.Int32, 0)},
            { "Array", new SequenceData(new SequenceDataType(UAOpcBinaryStandardDataTypes.Int32)) }
        };

        [NotNull]
        static private StructuredData IntegerArrayWithVariableLengthInBytes_CorrectSizeGivenData => new StructuredData(IntegerArrayWithVariableLengthInBytesDataType)
        {
            { "Size", new PrimitiveData(UAOpcBinaryStandardDataTypes.Int32, 12)},
            { "Array", new SequenceData(new SequenceDataType(UAOpcBinaryStandardDataTypes.Int32))
                {
                    new PrimitiveData(UAOpcBinaryStandardDataTypes.Int32, 161),
                    new PrimitiveData(UAOpcBinaryStandardDataTypes.Int32, 162),
                    new PrimitiveData(UAOpcBinaryStandardDataTypes.Int32, 163)
                }}
        };

        [NotNull]
        static private StructuredData IntegerArrayWithVariableLengthInBytes_IncorrectSizeGivenData => new StructuredData(IntegerArrayWithVariableLengthInBytesDataType)
        {
            { "Size", new PrimitiveData(UAOpcBinaryStandardDataTypes.Int32, 5)},
            { "Array", new SequenceData(new SequenceDataType(UAOpcBinaryStandardDataTypes.Int32))
            {
                new PrimitiveData(UAOpcBinaryStandardDataTypes.Int32, 161),
                new PrimitiveData(UAOpcBinaryStandardDataTypes.Int32, 162),
                new PrimitiveData(UAOpcBinaryStandardDataTypes.Int32, 163)
            }}
        };

        [NotNull]
        static private StructuredData IntegerArrayWithVariableLengthInBytes_NegativeSizeGivenData => new StructuredData(IntegerArrayWithVariableLengthInBytesDataType)
        {
            { "Size", new PrimitiveData(UAOpcBinaryStandardDataTypes.Int32, -2)},
            { "Array", new SequenceData(new SequenceDataType(UAOpcBinaryStandardDataTypes.Int32))
            {
                new PrimitiveData(UAOpcBinaryStandardDataTypes.Int32, 161),
                new PrimitiveData(UAOpcBinaryStandardDataTypes.Int32, 162),
                new PrimitiveData(UAOpcBinaryStandardDataTypes.Int32, 163)
            }}
        };

        [NotNull]
        static private StructuredData IntegerArrayWithVariableLengthInBytes_NegativeSizeAndNoArrayGivenData => new StructuredData(IntegerArrayWithVariableLengthInBytesDataType)
        {
            { "Size", new PrimitiveData(UAOpcBinaryStandardDataTypes.Int32, -1)}
        };

        [NotNull]
        static private StructuredData IntegerArrayWithVariableLengthInBytes_SizeWithPaddingGivenData => new StructuredData(IntegerArrayWithVariableLengthInBytesDataType)
        {
            { "Size", new PrimitiveData(UAOpcBinaryStandardDataTypes.Int32, 15)},
            { "Array", new SequenceData(new SequenceDataType(UAOpcBinaryStandardDataTypes.Int32))
            {
                new PrimitiveData(UAOpcBinaryStandardDataTypes.Int32, 161),
                new PrimitiveData(UAOpcBinaryStandardDataTypes.Int32, 162),
                new PrimitiveData(UAOpcBinaryStandardDataTypes.Int32, 163)
            }}
        };

        [NotNull]
        static private StructuredData IntegerArrayWithVariableLengthInBytes_NoSizeGivenData => new StructuredData(IntegerArrayWithVariableLengthInBytesDataType)
        {
            { "Array", new SequenceData(new SequenceDataType(UAOpcBinaryStandardDataTypes.Int32))
                {
                    new PrimitiveData(UAOpcBinaryStandardDataTypes.Int32, 161),
                    new PrimitiveData(UAOpcBinaryStandardDataTypes.Int32, 162),
                    new PrimitiveData(UAOpcBinaryStandardDataTypes.Int32, 163)
                }}
        };

        [NotNull]
        static private byte[] IntegerArrayWithVariableLengthInBytesExtensionObjectBody => new byte[]
            {12, 0, 0, 0, 161, 0, 0, 0, 162, 0, 0, 0, 163, 0, 0, 0};

        [NotNull]
        static private byte[] IntegerArrayWithVariableLengthInBytes_0ExtensionObjectBody => new byte[]
            {0, 0, 0, 0};

        [NotNull]
        static private byte[] IntegerArrayWithVariableLengthInBytes_NoArrayExtensionObjectBody => new byte[]
            {0xFF, 0xFF, 0xFF, 0xFF};

        [NotNull]
        static private byte[] IntegerArrayWithVariableLengthInBytes_WithPaddingExtensionObjectBody => new byte[]
            {15, 0, 0, 0, 161, 0, 0, 0, 162, 0, 0, 0, 163, 0, 0, 0, 0, 0, 0};

        [NotNull]
        static private byte[] IntegerArrayWithVariableLengthInBytes_WithPaddingTooShortExtensionObjectBody => new byte[]
            {15, 0, 0, 0, 161, 0, 0, 0, 162, 0, 0, 0, 163, 0, 0, 0, 0};

        #endregion



        #region Test Methods

        [TestMethod]
        public void DecodeErrorTest_BinaryDecoderPrematureEndOfEncodedStream_2() =>
            DecodeErrorTest(null,
                TypeDictionaryByteArray,
                "IntegerArrayWithVariableLengthInBytes",
                IntegerArrayWithVariableLengthInBytes_WithPaddingTooShortExtensionObjectBody,
                UADataTypeModelErrorCodes.OpcBinaryDictionaryDecoderPrematureEndOfEncodedStream);

        [TestMethod]
        public void DecodeTest_IntegerArrayWithVariableLengthInBytes_0() =>
            DecodeTest(null,
                TypeDictionaryByteArray,
                "IntegerArrayWithVariableLengthInBytes",
                IntegerArrayWithVariableLengthInBytes_0ExtensionObjectBody,
                IntegerArrayWithVariableLengthInBytes_0Data);

        [TestMethod]
        public void DecodeTest_IntegerArrayWithVariableLengthInBytes_CorrectSizeGiven() =>
            DecodeTest(null,
                TypeDictionaryByteArray,
                "IntegerArrayWithVariableLengthInBytes",
                IntegerArrayWithVariableLengthInBytesExtensionObjectBody,
                IntegerArrayWithVariableLengthInBytes_CorrectSizeGivenData);

        [TestMethod]
        public void DecodeTest_IntegerArrayWithVariableLengthInBytes_WithPadding() =>
            DecodeTest(null,
                TypeDictionaryByteArray,
                "IntegerArrayWithVariableLengthInBytes",
                IntegerArrayWithVariableLengthInBytes_WithPaddingExtensionObjectBody,
                IntegerArrayWithVariableLengthInBytes_SizeWithPaddingGivenData);

        [TestMethod]
        public void EncodeTest_IntegerArrayWithVariableLengthInBytes_0() =>
            EncodeTest(null, 
                TypeDictionaryByteArray,
                "IntegerArrayWithVariableLengthInBytes",
                IntegerArrayWithVariableLengthInBytes_0Data,
                IntegerArrayWithVariableLengthInBytes_0ExtensionObjectBody);

        [TestMethod]
        public void EncodeTest_IntegerArrayWithVariableLengthInBytes_EncodedNegativeSize() =>
            DecodeTest(null,
                TypeDictionaryByteArray,
                "IntegerArrayWithVariableLengthInBytes",
                IntegerArrayWithVariableLengthInBytes_NoArrayExtensionObjectBody,
                IntegerArrayWithVariableLengthInBytes_NegativeSizeAndNoArrayGivenData);

        [TestMethod]
        public void EncodeTest_IntegerArrayWithVariableLengthInBytes_CorrectSizeGiven() =>
            EncodeTest(null, 
                TypeDictionaryByteArray,
                "IntegerArrayWithVariableLengthInBytes",
                IntegerArrayWithVariableLengthInBytes_CorrectSizeGivenData,
                IntegerArrayWithVariableLengthInBytesExtensionObjectBody);

        [TestMethod]
        public void EncodeTest_IntegerArrayWithVariableLengthInBytes_IncorrectSizeGiven() =>
            EncodeTest(null, 
                TypeDictionaryByteArray,
                "IntegerArrayWithVariableLengthInBytes",
                IntegerArrayWithVariableLengthInBytes_IncorrectSizeGivenData,
                IntegerArrayWithVariableLengthInBytesExtensionObjectBody);

        [TestMethod]
        public void EncodeTest_IntegerArrayWithVariableLengthInBytes_NegativeSizeGiven() =>
            EncodeTest(null, 
                TypeDictionaryByteArray,
                "IntegerArrayWithVariableLengthInBytes",
                IntegerArrayWithVariableLengthInBytes_NegativeSizeGivenData,
                IntegerArrayWithVariableLengthInBytes_NoArrayExtensionObjectBody);

        [TestMethod]
        public void EncodeTest_IntegerArrayWithVariableLengthInBytes_NegativeSizeAndNoArrayGiven() =>
            EncodeTest(null, 
                TypeDictionaryByteArray,
                "IntegerArrayWithVariableLengthInBytes",
                IntegerArrayWithVariableLengthInBytes_NegativeSizeAndNoArrayGivenData,
                IntegerArrayWithVariableLengthInBytes_NoArrayExtensionObjectBody);

        [TestMethod]
        public void EncodeTest_IntegerArrayWithVariableLengthInBytes_NoSizeGiven() =>
            EncodeTest(null, 
                TypeDictionaryByteArray,
                "IntegerArrayWithVariableLengthInBytes",
                IntegerArrayWithVariableLengthInBytes_NoSizeGivenData,
                IntegerArrayWithVariableLengthInBytesExtensionObjectBody);

        #endregion
    }
}
