﻿
using System;
using System.Diagnostics;
using System.IO;
using JetBrains.Annotations;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using OpcLabs.BaseLib.DataTypeModel;
using OpcLabs.BaseLib.IO.Extensions;
using OpcLabs.EasyOpc.UA.DataTypeModel.Implementation;

namespace OpcLabs.EasyOpcTest.UA.DataTypeModel.Internal
{
    [TestClass]
    public class SelfImportingTest : UAOpcBinaryDataTypeSystemTest
    {
        #region Static Private Properties

        static private OpaqueDataType Int128DataType => new OpaqueDataType("Int128", "SelfImporting:Int128", 128);

        [NotNull]
        static private byte[] TypeDictionaryByteArray
        {
            get
            {
                Type type = typeof(UAOpcBinaryDataTypeSystemTest);
                Stream stream = type.Assembly.GetManifestResourceStream(type, "SelfImportingTypeDictionary.xml");
                Debug.Assert(stream != null);
                byte[] dictionaryByteArray = stream.ReadToArrayOfBytes();
                return dictionaryByteArray;
            }
        }

        #endregion



        #region Test Methods

        [TestMethod]
        public void DecodeErrorTest_ReferenceNonExistentType() =>
            DecodeErrorTest(null, TypeDictionaryByteArray, "AStructure2", new byte[16], UADataTypeModelErrorCodes.OpcBinarySystemTypeNotNotFoundInImports);

        [TestMethod]
        public void DecodeTest_NoReference()
        {
            DecodeTest(null, TypeDictionaryByteArray, "Int128",
                new byte[16],
                new OpaqueData(Int128DataType, new byte[16]));
        }

        [TestMethod]
        public void DecodeTest_ReferenceExistentType() =>
            DecodeTest(null, TypeDictionaryByteArray, "AStructure1", 
                new byte[16], 
                new StructuredData(new StructuredDataType("AStructure1", "SelfImporting:AStructure1") { new DataField("Value", Int128DataType) })
                {
                    {"Value", new OpaqueData(Int128DataType, new byte[16]) }
                });

        #endregion
    }
}
