﻿using System;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using OpcLabs.EasyOpc;
using OpcLabs.UnitTestLib;

namespace OpcLabs.EasyOpcTest
{
    partial class ServerDescriptorTest
    {
        #region Private Constants

        private const string TestClsidString = "214C35C3-91EB-45C2-9426-A5C4264C75BB";

        private const string TestClsidServerClass = "{" + TestClsidString + "}";

        #endregion



        #region Static Private Properties

        static private Guid TestClsid => Guid.Parse(TestClsidString);

        #endregion



        #region Test Methods

        [TestMethod]
        public void CtorTest_String_Empty()
        {
            var target = new ServerDescriptor("");
            Assert.AreEqual("", target.ToString());
            Assert.AreEqual("opcda", target.Scheme);
            Assert.AreEqual("", target.MachineName);
            Assert.AreEqual("", target.ProgId);
            Assert.AreEqual("", target.ServerClass);
            Assert.AreEqual("", target.ObjectId);
            Assert.AreEqual("", target.ClsidString);
            Assert.AreEqual(Guid.Empty, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_NoScheme_NoAuthority_Path1()
        {
            var target = new ServerDescriptor("testSegment");
            Assert.AreEqual("opcda:testSegment", target.ToString());
            Assert.AreEqual("opcda", target.Scheme);
            Assert.AreEqual("", target.MachineName);
            Assert.AreEqual("testSegment", target.ProgId);
            Assert.AreEqual("testSegment", target.ServerClass);
            Assert.AreEqual("testSegment", target.ObjectId);
            Assert.AreEqual("", target.ClsidString);
            Assert.AreEqual(Guid.Empty, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_NoScheme_NoAuthority_Path1_Clsid()
        {
            var target = new ServerDescriptor(TestClsidServerClass);
            Assert.AreEqual("opcda:" + TestClsidServerClass, target.ToString());
            Assert.AreEqual("opcda", target.Scheme);
            Assert.AreEqual("", target.MachineName);
            Assert.AreEqual("", target.ProgId);
            Assert.AreEqual(TestClsidServerClass.ToLower(), target.ServerClass);
            Assert.AreEqual(TestClsidServerClass.ToLower(), target.ObjectId);
            Assert.AreEqual(TestClsidString.ToLower(), target.ClsidString);
            Assert.AreEqual(TestClsid, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_NoScheme_NoAuthority_Path2()
        {
            var target = new ServerDescriptor("/testSegment");
            Assert.AreEqual("opcda:/testSegment", target.ToString());
            Assert.AreEqual("opcda", target.Scheme);
            Assert.AreEqual("", target.MachineName);
            Assert.AreEqual("testSegment", target.ProgId);
            Assert.AreEqual("testSegment", target.ServerClass);
            Assert.AreEqual("testSegment", target.ObjectId);
            Assert.AreEqual("", target.ClsidString);
            Assert.AreEqual(Guid.Empty, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_NoScheme_NoAuthority_Path2_Clsid()
        {
            var target = new ServerDescriptor("/" + TestClsidServerClass);
            Assert.AreEqual("opcda:/" + TestClsidServerClass, target.ToString());
            Assert.AreEqual("opcda", target.Scheme);
            Assert.AreEqual("", target.MachineName);
            Assert.AreEqual("", target.ProgId);
            Assert.AreEqual(TestClsidServerClass.ToLower(), target.ServerClass);
            Assert.AreEqual(TestClsidServerClass.ToLower(), target.ObjectId);
            Assert.AreEqual(TestClsidString.ToLower(), target.ClsidString);
            Assert.AreEqual(TestClsid, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_NoScheme_NoAuthority_Path3()
        {
            var target = new ServerDescriptor("testSegment1/testSegment2");
            Assert.AreEqual("opcda:testSegment1/testSegment2", target.ToString());
            Assert.AreEqual("opcda", target.Scheme);
            Assert.AreEqual("", target.MachineName);
            Assert.AreEqual("testSegment1", target.ProgId);
            Assert.AreEqual("testSegment1", target.ServerClass);
            Assert.AreEqual("testSegment1", target.ObjectId);
            Assert.AreEqual("", target.ClsidString);
            Assert.AreEqual(Guid.Empty, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_NoScheme_NoAuthority_Path3_Clsid()
        {
            var target = new ServerDescriptor("testSegment1/" + TestClsidServerClass);
            Assert.AreEqual("opcda:testSegment1/" + TestClsidServerClass, target.ToString());
            Assert.AreEqual("opcda", target.Scheme);
            Assert.AreEqual("", target.MachineName);
            Assert.AreEqual("testSegment1", target.ProgId);
            Assert.AreEqual("testSegment1", target.ServerClass);
            Assert.AreEqual("testSegment1/" + TestClsidServerClass.ToLower(), target.ObjectId);
            Assert.AreEqual(TestClsidString.ToLower(), target.ClsidString);
            Assert.AreEqual(TestClsid, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_NoScheme_NoAuthority_Path4()
        {
            var target = new ServerDescriptor("/testSegment1/testSegment2");
            Assert.AreEqual("opcda:/testSegment1/testSegment2", target.ToString());
            Assert.AreEqual("opcda", target.Scheme);
            Assert.AreEqual("", target.MachineName);
            Assert.AreEqual("testSegment1", target.ProgId);
            Assert.AreEqual("testSegment1", target.ServerClass);
            Assert.AreEqual("testSegment1", target.ObjectId);
            Assert.AreEqual("", target.ClsidString);
            Assert.AreEqual(Guid.Empty, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_NoScheme_NoAuthority_Path4_Clsid()
        {
            var target = new ServerDescriptor("/testSegment1/" + TestClsidServerClass);
            Assert.AreEqual("opcda:/testSegment1/" + TestClsidServerClass, target.ToString());
            Assert.AreEqual("opcda", target.Scheme);
            Assert.AreEqual("", target.MachineName);
            Assert.AreEqual("testSegment1", target.ProgId);
            Assert.AreEqual("testSegment1", target.ServerClass);
            Assert.AreEqual("testSegment1/" + TestClsidServerClass.ToLower(), target.ObjectId);
            Assert.AreEqual(TestClsidString.ToLower(), target.ClsidString);
            Assert.AreEqual(TestClsid, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_NoScheme_NoAuthority_Path5()
        {
            var target = new ServerDescriptor("/testSegment1/testSegment2/testSegment3");
            Assert.AreEqual("opcda:/testSegment1/testSegment2/testSegment3", target.ToString());
            Assert.AreEqual("opcda", target.Scheme);
            Assert.AreEqual("", target.MachineName);
            Assert.AreEqual("testSegment1", target.ProgId);
            Assert.AreEqual("testSegment1", target.ServerClass);
            Assert.AreEqual("testSegment1", target.ObjectId);
            Assert.AreEqual("", target.ClsidString);
            Assert.AreEqual(Guid.Empty, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_NoScheme_NoAuthority_Path5_Clsid()
        {
            var target = new ServerDescriptor("/testSegment1/" + TestClsidServerClass + "/testSegment3");
            Assert.AreEqual("opcda:/testSegment1/" + TestClsidServerClass + "/testSegment3", target.ToString());
            Assert.AreEqual("opcda", target.Scheme);
            Assert.AreEqual("", target.MachineName);
            Assert.AreEqual("testSegment1", target.ProgId);
            Assert.AreEqual("testSegment1", target.ServerClass);
            Assert.AreEqual("testSegment1/" + TestClsidServerClass.ToLower(), target.ObjectId);
            Assert.AreEqual(TestClsidString.ToLower(), target.ClsidString);
            Assert.AreEqual(TestClsid, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_NoScheme_Authority_NoPath()
        {
            var target = new ServerDescriptor("//testAuthority");
            Assert.AreEqual("opcda://testAuthority", target.ToString());
            Assert.AreEqual("opcda", target.Scheme);
            Assert.AreEqual("testauthority", target.MachineName);
            Assert.AreEqual("", target.ProgId);
            Assert.AreEqual("", target.ServerClass);
            Assert.AreEqual("", target.ObjectId);
            Assert.AreEqual("", target.ClsidString);
            Assert.AreEqual(Guid.Empty, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_NoScheme_Authority_Path1()
        {
            var target = new ServerDescriptor("//testAuthority/testSegment");
            Assert.AreEqual("opcda://testAuthority/testSegment", target.ToString());
            Assert.AreEqual("opcda", target.Scheme);
            Assert.AreEqual("testauthority", target.MachineName);
            Assert.AreEqual("testSegment", target.ProgId);
            Assert.AreEqual("testSegment", target.ServerClass);
            Assert.AreEqual("testSegment", target.ObjectId);
            Assert.AreEqual("", target.ClsidString);
            Assert.AreEqual(Guid.Empty, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_NoScheme_Authority_Path1_Clsid()
        {
            var target = new ServerDescriptor("//testAuthority/" + TestClsidServerClass);
            Assert.AreEqual("opcda://testAuthority/" + TestClsidServerClass, target.ToString());
            Assert.AreEqual("opcda", target.Scheme);
            Assert.AreEqual("testauthority", target.MachineName);
            Assert.AreEqual("", target.ProgId);
            Assert.AreEqual(TestClsidServerClass.ToLower(), target.ServerClass);
            Assert.AreEqual(TestClsidServerClass.ToLower(), target.ObjectId);
            Assert.AreEqual(TestClsidString.ToLower(), target.ClsidString);
            Assert.AreEqual(TestClsid, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_Scheme_NoAuthority_Path1()
        {
            var target = new ServerDescriptor("testScheme:testSegment");
            Assert.AreEqual("testScheme:testSegment", target.ToString());
            Assert.AreEqual("testscheme", target.Scheme);
            Assert.AreEqual("", target.MachineName);
            Assert.AreEqual("testSegment", target.ProgId);
            Assert.AreEqual("testSegment", target.ServerClass);
            Assert.AreEqual("testSegment", target.ObjectId);
            Assert.AreEqual("", target.ClsidString);
            Assert.AreEqual(Guid.Empty, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_Scheme_NoAuthority_Path1_Clsid()
        {
            var target = new ServerDescriptor("testScheme:" + TestClsidServerClass);
            Assert.AreEqual("testScheme:" + TestClsidServerClass, target.ToString());
            Assert.AreEqual("testscheme", target.Scheme);
            Assert.AreEqual("", target.MachineName);
            Assert.AreEqual("", target.ProgId);
            Assert.AreEqual(TestClsidServerClass.ToLower(), target.ServerClass);
            Assert.AreEqual(TestClsidServerClass.ToLower(), target.ObjectId);
            Assert.AreEqual(TestClsidString.ToLower(), target.ClsidString);
            Assert.AreEqual(TestClsid, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_Scheme_NoAuthority_Path2()
        {
            var target = new ServerDescriptor("testScheme:/testSegment");
            Assert.AreEqual("testScheme:/testSegment", target.ToString());
            Assert.AreEqual("testscheme", target.Scheme);
            Assert.AreEqual("", target.MachineName);
            Assert.AreEqual("testSegment", target.ProgId);
            Assert.AreEqual("testSegment", target.ServerClass);
            Assert.AreEqual("testSegment", target.ObjectId);
            Assert.AreEqual("", target.ClsidString);
            Assert.AreEqual(Guid.Empty, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_Scheme_NoAuthority_Path2_Clsid()
        {
            var target = new ServerDescriptor("testScheme:/" + TestClsidServerClass);
            Assert.AreEqual("testScheme:/" + TestClsidServerClass, target.ToString());
            Assert.AreEqual("testscheme", target.Scheme);
            Assert.AreEqual("", target.MachineName);
            Assert.AreEqual("", target.ProgId);
            Assert.AreEqual(TestClsidServerClass.ToLower(), target.ServerClass);
            Assert.AreEqual(TestClsidServerClass.ToLower(), target.ObjectId);
            Assert.AreEqual(TestClsidString.ToLower(), target.ClsidString);
            Assert.AreEqual(TestClsid, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_Scheme_NoAuthority_Path3()
        {
            var target = new ServerDescriptor("testScheme:testSegment1/testSegment2");
            Assert.AreEqual("testScheme:testSegment1/testSegment2", target.ToString());
            Assert.AreEqual("testscheme", target.Scheme);
            Assert.AreEqual("", target.MachineName);
            Assert.AreEqual("testSegment1", target.ProgId);
            Assert.AreEqual("testSegment1", target.ServerClass);
            Assert.AreEqual("testSegment1", target.ObjectId);
            Assert.AreEqual("", target.ClsidString);
            Assert.AreEqual(Guid.Empty, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_Scheme_NoAuthority_Path3_Clsid()
        {
            var target = new ServerDescriptor("testScheme:testSegment1/" + TestClsidServerClass);
            Assert.AreEqual("testScheme:testSegment1/" + TestClsidServerClass, target.ToString());
            Assert.AreEqual("testscheme", target.Scheme);
            Assert.AreEqual("", target.MachineName);
            Assert.AreEqual("testSegment1", target.ProgId);
            Assert.AreEqual("testSegment1", target.ServerClass);
            Assert.AreEqual("testSegment1/" + TestClsidServerClass.ToLower(), target.ObjectId);
            Assert.AreEqual(TestClsidString.ToLower(), target.ClsidString);
            Assert.AreEqual(TestClsid, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_Scheme_NoAuthority_Path4()
        {
            var target = new ServerDescriptor("testScheme:/testSegment1/testSegment2");
            Assert.AreEqual("testScheme:/testSegment1/testSegment2", target.ToString());
            Assert.AreEqual("testscheme", target.Scheme);
            Assert.AreEqual("", target.MachineName);
            Assert.AreEqual("testSegment1", target.ProgId);
            Assert.AreEqual("testSegment1", target.ServerClass);
            Assert.AreEqual("testSegment1", target.ObjectId);
            Assert.AreEqual("", target.ClsidString);
            Assert.AreEqual(Guid.Empty, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_Scheme_NoAuthority_Path4_Clsid()
        {
            var target = new ServerDescriptor("testScheme:/testSegment1/" + TestClsidServerClass);
            Assert.AreEqual("testScheme:/testSegment1/" + TestClsidServerClass, target.ToString());
            Assert.AreEqual("testscheme", target.Scheme);
            Assert.AreEqual("", target.MachineName);
            Assert.AreEqual("testSegment1", target.ProgId);
            Assert.AreEqual("testSegment1", target.ServerClass);
            Assert.AreEqual("testSegment1/" + TestClsidServerClass.ToLower(), target.ObjectId);
            Assert.AreEqual(TestClsidString.ToLower(), target.ClsidString);
            Assert.AreEqual(TestClsid, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_Scheme_NoAuthority_Path5()
        {
            var target = new ServerDescriptor("testScheme:testSegment1/testSegment2/testSegment3");
            Assert.AreEqual("testScheme:testSegment1/testSegment2/testSegment3", target.ToString());
            Assert.AreEqual("testscheme", target.Scheme);
            Assert.AreEqual("", target.MachineName);
            Assert.AreEqual("testSegment1", target.ProgId);
            Assert.AreEqual("testSegment1", target.ServerClass);
            Assert.AreEqual("testSegment1", target.ObjectId);
            Assert.AreEqual("", target.ClsidString);
            Assert.AreEqual(Guid.Empty, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_Scheme_NoAuthority_Path5_Clsid()
        {
            var target = new ServerDescriptor("testScheme:testSegment1/" + TestClsidServerClass + "/testSegment3");
            Assert.AreEqual("testScheme:testSegment1/" + TestClsidServerClass + "/testSegment3", target.ToString());
            Assert.AreEqual("testscheme", target.Scheme);
            Assert.AreEqual("", target.MachineName);
            Assert.AreEqual("testSegment1", target.ProgId);
            Assert.AreEqual("testSegment1", target.ServerClass);
            Assert.AreEqual("testSegment1/" + TestClsidServerClass.ToLower(), target.ObjectId);
            Assert.AreEqual(TestClsidString.ToLower(), target.ClsidString);
            Assert.AreEqual(TestClsid, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_Scheme_NoAuthority_Path6()
        {
            var target = new ServerDescriptor("testScheme:/testSegment1/testSegment2/testSegment3");
            Assert.AreEqual("testScheme:/testSegment1/testSegment2/testSegment3", target.ToString());
            Assert.AreEqual("testscheme", target.Scheme);
            Assert.AreEqual("", target.MachineName);
            Assert.AreEqual("testSegment1", target.ProgId);
            Assert.AreEqual("testSegment1", target.ServerClass);
            Assert.AreEqual("testSegment1", target.ObjectId);
            Assert.AreEqual("", target.ClsidString);
            Assert.AreEqual(Guid.Empty, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_Scheme_NoAuthority_Path6_Clsid()
        {
            var target = new ServerDescriptor("testScheme:/testSegment1/" + TestClsidServerClass + "/testSegment3");
            Assert.AreEqual("testScheme:/testSegment1/" + TestClsidServerClass + "/testSegment3", target.ToString());
            Assert.AreEqual("testscheme", target.Scheme);
            Assert.AreEqual("", target.MachineName);
            Assert.AreEqual("testSegment1", target.ProgId);
            Assert.AreEqual("testSegment1", target.ServerClass);
            Assert.AreEqual("testSegment1/" + TestClsidServerClass.ToLower(), target.ObjectId);
            Assert.AreEqual(TestClsidString.ToLower(), target.ClsidString);
            Assert.AreEqual(TestClsid, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_Scheme_Authority_Path1()
        {
            var target = new ServerDescriptor("testScheme://testAuthority/testSegment");
            Assert.AreEqual("testScheme://testAuthority/testSegment", target.ToString());
            Assert.AreEqual("testscheme", target.Scheme);
            Assert.AreEqual("testauthority", target.MachineName);
            Assert.AreEqual("testSegment", target.ProgId);
            Assert.AreEqual("testSegment", target.ServerClass);
            Assert.AreEqual("testSegment", target.ObjectId);
            Assert.AreEqual("", target.ClsidString);
            Assert.AreEqual(Guid.Empty, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_Scheme_Authority_Path1_Clsid()
        {
            var target = new ServerDescriptor("testScheme://testAuthority/" + TestClsidServerClass);
            Assert.AreEqual("testScheme://testAuthority/" + TestClsidServerClass, target.ToString());
            Assert.AreEqual("testscheme", target.Scheme);
            Assert.AreEqual("testauthority", target.MachineName);
            Assert.AreEqual("", target.ProgId);
            Assert.AreEqual(TestClsidServerClass.ToLower(), target.ServerClass);
            Assert.AreEqual(TestClsidServerClass.ToLower(), target.ObjectId);
            Assert.AreEqual(TestClsidString.ToLower(), target.ClsidString);
            Assert.AreEqual(TestClsid, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_Scheme_Authority_Path2()
        {
            var target = new ServerDescriptor("testScheme://testAuthority//testSegment");
            Assert.AreEqual("testScheme://testAuthority//testSegment", target.ToString());
            Assert.AreEqual("testscheme", target.Scheme);
            Assert.AreEqual("testauthority", target.MachineName);
            Assert.AreEqual("", target.ProgId);
            Assert.AreEqual("", target.ServerClass);
            Assert.AreEqual("", target.ObjectId);
            Assert.AreEqual("", target.ClsidString);
            Assert.AreEqual(Guid.Empty, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_Scheme_Authority_Path2_Clsid()
        {
            var target = new ServerDescriptor("testScheme://testAuthority//" + TestClsidServerClass);
            Assert.AreEqual("testScheme://testAuthority//" + TestClsidServerClass, target.ToString());
            Assert.AreEqual("testscheme", target.Scheme);
            Assert.AreEqual("testauthority", target.MachineName);
            Assert.AreEqual("", target.ProgId);
            Assert.AreEqual(TestClsidServerClass.ToLower(), target.ServerClass);
            Assert.AreEqual(TestClsidServerClass.ToLower(), target.ObjectId);
            Assert.AreEqual(TestClsidString.ToLower(), target.ClsidString);
            Assert.AreEqual(TestClsid, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_Scheme_Authority_Path3()
        {
            var target = new ServerDescriptor("testScheme://testAuthority/testSegment1/testSegment2");
            Assert.AreEqual("testScheme://testAuthority/testSegment1/testSegment2", target.ToString());
            Assert.AreEqual("testscheme", target.Scheme);
            Assert.AreEqual("testauthority", target.MachineName);
            Assert.AreEqual("testSegment1", target.ProgId);
            Assert.AreEqual("testSegment1", target.ServerClass);
            Assert.AreEqual("testSegment1", target.ObjectId);
            Assert.AreEqual("", target.ClsidString);
            Assert.AreEqual(Guid.Empty, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_Scheme_Authority_Path3_Clsid()
        {
            var target = new ServerDescriptor("testScheme://testAuthority/testSegment1/" + TestClsidServerClass);
            Assert.AreEqual("testScheme://testAuthority/testSegment1/" + TestClsidServerClass, target.ToString());
            Assert.AreEqual("testscheme", target.Scheme);
            Assert.AreEqual("testauthority", target.MachineName);
            Assert.AreEqual("testSegment1", target.ProgId);
            Assert.AreEqual("testSegment1", target.ServerClass);
            Assert.AreEqual("testSegment1/" + TestClsidServerClass.ToLower(), target.ObjectId);
            Assert.AreEqual(TestClsidString.ToLower(), target.ClsidString);
            Assert.AreEqual(TestClsid, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_Scheme_Authority_Path4()
        {
            var target = new ServerDescriptor("testScheme://testAuthority//testSegment1/testSegment2");
            Assert.AreEqual("testScheme://testAuthority//testSegment1/testSegment2", target.ToString());
            Assert.AreEqual("testscheme", target.Scheme);
            Assert.AreEqual("testauthority", target.MachineName);
            Assert.AreEqual("", target.ProgId);
            Assert.AreEqual("", target.ServerClass);
            Assert.AreEqual("", target.ObjectId);
            Assert.AreEqual("", target.ClsidString);
            Assert.AreEqual(Guid.Empty, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_Scheme_Authority_Path4_Clsid()
        {
            var target = new ServerDescriptor("testScheme://testAuthority//testSegment1/" + TestClsidServerClass);
            Assert.AreEqual("testScheme://testAuthority//testSegment1/" + TestClsidServerClass, target.ToString());
            Assert.AreEqual("testscheme", target.Scheme);
            Assert.AreEqual("testauthority", target.MachineName);
            Assert.AreEqual("", target.ProgId);
            Assert.AreEqual("", target.ServerClass);
            Assert.AreEqual("", target.ObjectId);
            Assert.AreEqual("", target.ClsidString);
            Assert.AreEqual(Guid.Empty, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_Scheme_Authority_Path5()
        {
            var target = new ServerDescriptor("testScheme://testAuthority/testSegment1/testSegment2/testSegment3");
            Assert.AreEqual("testScheme://testAuthority/testSegment1/testSegment2/testSegment3", target.ToString());
            Assert.AreEqual("testscheme", target.Scheme);
            Assert.AreEqual("testauthority", target.MachineName);
            Assert.AreEqual("testSegment1", target.ProgId);
            Assert.AreEqual("testSegment1", target.ServerClass);
            Assert.AreEqual("testSegment1", target.ObjectId);
            Assert.AreEqual("", target.ClsidString);
            Assert.AreEqual(Guid.Empty, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_Scheme_Authority_Path5_Clsid()
        {
            var target = new ServerDescriptor("testScheme://testAuthority/testSegment1/" + TestClsidServerClass + "/testSegment3");
            Assert.AreEqual("testScheme://testAuthority/testSegment1/" + TestClsidServerClass + "/testSegment3", target.ToString());
            Assert.AreEqual("testscheme", target.Scheme);
            Assert.AreEqual("testauthority", target.MachineName);
            Assert.AreEqual("testSegment1", target.ProgId);
            Assert.AreEqual("testSegment1", target.ServerClass);
            Assert.AreEqual("testSegment1/" + TestClsidServerClass.ToLower(), target.ObjectId);
            Assert.AreEqual(TestClsidString.ToLower(), target.ClsidString);
            Assert.AreEqual(TestClsid, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_Scheme_Authority_Path6()
        {
            var target = new ServerDescriptor("testScheme://testAuthority//testSegment1/testSegment2/testSegment3");
            Assert.AreEqual("testScheme://testAuthority//testSegment1/testSegment2/testSegment3", target.ToString());
            Assert.AreEqual("testscheme", target.Scheme);
            Assert.AreEqual("testauthority", target.MachineName);
            Assert.AreEqual("", target.ProgId);
            Assert.AreEqual("", target.ServerClass);
            Assert.AreEqual("", target.ObjectId);
            Assert.AreEqual("", target.ClsidString);
            Assert.AreEqual(Guid.Empty, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_Scheme_Authority_Path6_Clsid()
        {
            var target = new ServerDescriptor("testScheme://testAuthority//testSegment1/" + TestClsidServerClass + "/testSegment3");
            Assert.AreEqual("testScheme://testAuthority//testSegment1/" + TestClsidServerClass + "/testSegment3", target.ToString());
            Assert.AreEqual("testscheme", target.Scheme);
            Assert.AreEqual("testauthority", target.MachineName);
            Assert.AreEqual("", target.ProgId);
            Assert.AreEqual("", target.ServerClass);
            Assert.AreEqual("", target.ObjectId);
            Assert.AreEqual("", target.ClsidString);
            Assert.AreEqual(Guid.Empty, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_String_Empty_Empty()
        {
            var target = new ServerDescriptor("", "");
            Assert.AreEqual("opcda:", target.UrlString);
            Assert.AreEqual("opcda", target.Scheme);
            Assert.AreEqual("", target.MachineName);
            Assert.AreEqual("", target.ProgId);
            Assert.AreEqual("", target.ServerClass);
            Assert.AreEqual("", target.ObjectId);
            Assert.AreEqual("", target.ClsidString);
            Assert.AreEqual(Guid.Empty, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_String_Empty_NotEmpty()
        {
            var target = new ServerDescriptor("", "testServerClass");
            Assert.AreEqual("opcda:testServerClass", target.UrlString);
            Assert.AreEqual("opcda", target.Scheme);
            Assert.AreEqual("", target.MachineName);
            Assert.AreEqual("testServerClass", target.ProgId);
            Assert.AreEqual("testServerClass", target.ServerClass);
            Assert.AreEqual("testServerClass", target.ObjectId);
            Assert.AreEqual("", target.ClsidString);
            Assert.AreEqual(Guid.Empty, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_String_Empty_NotEmpty_Clsid()
        {
            var target = new ServerDescriptor("", TestClsidServerClass);
            Assert.AreEqual("opcda:" + Uri.EscapeDataString(TestClsidServerClass.ToLower()), target.UrlString);
            Assert.AreEqual("opcda", target.Scheme);
            Assert.AreEqual("", target.MachineName);
            Assert.AreEqual("", target.ProgId);
            Assert.AreEqual(TestClsidServerClass.ToLower(), target.ServerClass);
            Assert.AreEqual(TestClsidServerClass, target.ObjectId);
            Assert.AreEqual(TestClsidString.ToLower(), target.ClsidString);
            Assert.AreEqual(TestClsid, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_String_NotEmpty_Empty()
        {
            var target = new ServerDescriptor("machineName", "");
            Assert.AreEqual("opcda://machineName/", target.UrlString);
            Assert.AreEqual("opcda", target.Scheme);
            Assert.AreEqual("machineName", target.MachineName);
            Assert.AreEqual("", target.ProgId);
            Assert.AreEqual("", target.ServerClass);
            Assert.AreEqual("", target.ObjectId);
            Assert.AreEqual("", target.ClsidString);
            Assert.AreEqual(Guid.Empty, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_String_NotEmpty_NotEmpty()
        {
            var target = new ServerDescriptor("testMachineName", "testServerClass");
            Assert.AreEqual("opcda://testmachinename/testServerClass", target.UrlString);
            Assert.AreEqual("opcda", target.Scheme);
            Assert.AreEqual("testMachineName", target.MachineName);
            Assert.AreEqual("testServerClass", target.ProgId);
            Assert.AreEqual("testServerClass", target.ServerClass);
            Assert.AreEqual("testServerClass", target.ObjectId);
            Assert.AreEqual("", target.ClsidString);
            Assert.AreEqual(Guid.Empty, target.Clsid);
        }

        [TestMethod]
        public void CtorTest_String_String_NotEmpty_NotEmpty_Clsid()
        {
            var target = new ServerDescriptor("testMachineName", TestClsidServerClass);
            Assert.AreEqual("opcda://testmachinename/" + Uri.EscapeDataString(TestClsidServerClass.ToLower()), target.UrlString);
            Assert.AreEqual("opcda", target.Scheme);
            Assert.AreEqual("testMachineName", target.MachineName);
            Assert.AreEqual("", target.ProgId);
            Assert.AreEqual(TestClsidServerClass.ToLower(), target.ServerClass);
            Assert.AreEqual(TestClsidServerClass, target.ObjectId);
            Assert.AreEqual(TestClsidString.ToLower(), target.ClsidString);
            Assert.AreEqual(TestClsid, target.Clsid);
        }

        [TestMethod]
        public void EquivalenceTest_Negative_1()
        {
            var first = new ServerDescriptor();
            var second = new ServerDescriptor("testDescriptorString");
            Assert.IsFalse(first.Equals(/*(object)*/second));
        }

        [TestMethod]
        public void EquivalenceTest_Negative_2()
        {
            var first = new ServerDescriptor("testDescriptorString1");
            var second = new ServerDescriptor("testDescriptorString2");
            Assert.IsFalse(first.Equals(/*(object)*/second));
        }

        [TestMethod]
        public void EquivalenceTest_Negative_3()
        {
            var first = new ServerDescriptor("testDescriptorString");
            var second = new ServerDescriptor();
            Assert.IsFalse(first.Equals(/*(object)*/second));
        }

        [TestMethod]
        public void IsNullTest_Negative()
        {
            var target = new ServerDescriptor("testMachineName");
            Assert.IsFalse(target.IsNull);
        }

        [TestMethod]
        public void IsNullTest_Positive()
        {
            var target = ServerDescriptor.Null;
            Assert.IsTrue(target.IsNull);
        }

        [TestMethod]
        public void MachineNameTest_AssignAfterServerClass()
        {
            var target = new ServerDescriptor { ServerClass = "testServerClass", MachineName = "testMachineName" };
            Assert.AreEqual("opcda://testMachineName/testServerClass", target.ToString());
            Assert.AreEqual("testMachineName", target.MachineName);
        }

        [TestMethod]
        public void MachineNameTest_AssignToNew()
        {
            var target = new ServerDescriptor { MachineName = "testMachineName" };
            Assert.AreEqual("opcda://testMachineName/", target.ToString());
            Assert.AreEqual("testMachineName", target.MachineName);
        }

        [TestMethod]
        public void MachineNameTest_FromUri_1()
        {
            var target = new ServerDescriptor { UrlString = "testScheme://testMachineName" };
            Assert.AreEqual("testmachinename", target.MachineName);
        }

        [TestMethod]
        public void MachineNameTest_FromUri_2()
        {
            var target = new ServerDescriptor { UrlString = "testScheme://testMachineName/" };
            Assert.AreEqual("testmachinename", target.MachineName);
        }

        [TestMethod]
        public void MachineNameTest_FromUri_3()
        {
            var target = new ServerDescriptor { UrlString = "testScheme://testMachineName/testPath" };
            Assert.AreEqual("testmachinename", target.MachineName);
        }

        [TestMethod]
        public void MachineNameTest_FromUri_4()
        {
            var target = new ServerDescriptor
            {
                UrlString = "testScheme://testUser:testPassword@testMachineName/testPath"
            };
            Assert.AreEqual("testmachinename", target.MachineName);
        }

        [TestMethod]
        public void ServerClassTest_AssignAfterMachineName()
        {
            var target = new ServerDescriptor { MachineName = "testMachineName", ServerClass = "testServerClass" };
            Assert.AreEqual("opcda://testmachinename/testServerClass", target.UrlString);
            Assert.AreEqual("opcda://testmachinename/testServerClass", target.ToString());
            Assert.AreEqual("testServerClass", target.ServerClass);
        }

        [TestMethod]
        public void ServerClassTest_AssignAfterMachineName_Clsid()
        {
            var target = new ServerDescriptor { MachineName = "testMachineName", ServerClass = TestClsidServerClass };
            Assert.AreEqual("opcda://testmachinename/" + Uri.EscapeDataString(TestClsidServerClass.ToLower()), target.UrlString);
            Assert.AreEqual("opcda://testmachinename/" + TestClsidServerClass.ToLower(), target.ToString());
            Assert.AreEqual(TestClsidServerClass, target.ServerClass);
        }

        [TestMethod]
        public void ServerClassTest_AssignToNew()
        {
            var target = new ServerDescriptor { ServerClass = "testServerClass" };
            Assert.AreEqual("opcda:testServerClass", target.UrlString);
            Assert.AreEqual("opcda:testServerClass", target.ToString());
            Assert.AreEqual("testServerClass", target.ServerClass);
        }

        [TestMethod]
        public void ServerClassTest_AssignToNew_Clsid()
        {
            var target = new ServerDescriptor { ServerClass = TestClsidServerClass };
            Assert.AreEqual("opcda:" + Uri.EscapeDataString(TestClsidServerClass.ToLower()), target.UrlString);
            Assert.AreEqual("opcda:" + TestClsidServerClass.ToLower(), target.ToString());
            Assert.AreEqual(TestClsidServerClass, target.ServerClass);
        }

        [TestMethod]
        public void ServerClassTest_FromUri_1()
        {
            var target = new ServerDescriptor { UrlString = "testScheme://" };
            Assert.AreEqual("", target.ServerClass);
        }

        [TestMethod]
        public void ServerClassTest_FromUri_2()
        {
            var target = new ServerDescriptor { UrlString = "testScheme://testMachineName" };
            Assert.AreEqual("", target.ServerClass);
        }

        [TestMethod]
        public void ServerClassTest_FromUri_3()
        {
            var target = new ServerDescriptor { UrlString = "testScheme://testMachineName/" };
            Assert.AreEqual("", target.ServerClass);
        }

        [TestMethod]
        public void ServerClassTest_FromUri_4()
        {
            var target = new ServerDescriptor { UrlString = "testScheme:testServerClass" };
            Assert.AreEqual("testServerClass", target.ServerClass);
        }

        [TestMethod]
        public void ServerClassTest_FromUri_4_Clsid()
        {
            var target = new ServerDescriptor { UrlString = "testScheme:" + TestClsidServerClass };
            Assert.AreEqual(TestClsidServerClass.ToLower(), target.ServerClass);
        }

        [TestMethod]
        // ReSharper disable once InconsistentNaming
        public void ServerClassTest_FromUri_4a()
        {
            var target = new ServerDescriptor { UrlString = "testScheme:/testServerClass" };
            Assert.AreEqual("testServerClass", target.ServerClass);
        }

        [TestMethod]
        // ReSharper disable once InconsistentNaming
        public void ServerClassTest_FromUri_4a_Clsid()
        {
            var target = new ServerDescriptor { UrlString = "testScheme:/" + TestClsidServerClass };
            Assert.AreEqual(TestClsidServerClass.ToLower(), target.ServerClass);
        }

        [TestMethod]
        public void ServerClassTest_FromUri_5()
        {
            var target = new ServerDescriptor { UrlString = "testScheme:///testServerClass" };
            Assert.AreEqual("testServerClass", target.ServerClass);
        }

        [TestMethod]
        public void ServerClassTest_FromUri_5_Clsid()
        {
            var target = new ServerDescriptor { UrlString = "testScheme:///" + TestClsidServerClass };
            Assert.AreEqual(TestClsidServerClass.ToLower(), target.ServerClass);
        }

        [TestMethod]
        // ReSharper disable once InconsistentNaming
        public void ServerClassTest_FromUri_5a()
        {
            var target = new ServerDescriptor { UrlString = "testScheme:////testServerClass" };
            Assert.AreEqual("", target.ServerClass);
        }

        [TestMethod]
        // ReSharper disable once InconsistentNaming
        public void ServerClassTest_FromUri_5a_Clsid()
        {
            var target = new ServerDescriptor { UrlString = "testScheme:////" + TestClsidServerClass };
            Assert.AreEqual(TestClsidServerClass.ToLower(), target.ServerClass);
        }

        [TestMethod]
        public void ServerClassTest_FromUri_6()
        {
            var target = new ServerDescriptor { UrlString = "testScheme://testMachineName/testServerClass" };
            Assert.AreEqual("testServerClass", target.ServerClass);
        }

        [TestMethod]
        public void ServerClassTest_FromUri_6_Clsid()
        {
            var target = new ServerDescriptor { UrlString = "testScheme://testMachineName/" + TestClsidServerClass };
            Assert.AreEqual(TestClsidServerClass.ToLower(), target.ServerClass);
        }

        [TestMethod]
        // ReSharper disable once InconsistentNaming
        public void ServerClassTest_FromUri_6a()
        {
            var target = new ServerDescriptor { UrlString = "testScheme://testMachineName//testServerClass" };
            Assert.AreEqual("", target.ServerClass);
        }

        [TestMethod]
        // ReSharper disable once InconsistentNaming
        public void ServerClassTest_FromUri_6a_Clsid()
        {
            var target = new ServerDescriptor { UrlString = "testScheme://testMachineName//" + TestClsidServerClass };
            Assert.AreEqual(TestClsidServerClass.ToLower(), target.ServerClass);
        }

        [TestMethod]
        public void ToStringTest_MachineNameAndServerClass()
        {
            var target = new ServerDescriptor("testMachineName", "testServerClass");
            Assert.AreEqual("opcda://testmachinename/testServerClass", target.UrlString);
            Assert.AreEqual("opcda://testmachinename/testServerClass", target.ToString());
        }

        [TestMethod]
        public void ToStringTest_MachineNameAndServerClass_Clsid()
        {
            var target = new ServerDescriptor("testMachineName", TestClsidServerClass);
            Assert.AreEqual("opcda://testmachinename/" + Uri.EscapeDataString(TestClsidServerClass.ToLower()), target.UrlString);
            Assert.AreEqual("opcda://testmachinename/" + TestClsidServerClass.ToLower(), target.ToString());
        }

        [TestMethod]
        public void ToStringTest_MachineNameOnly()
        {
            var target = new ServerDescriptor("testMachineName", "");
            Assert.AreEqual("opcda://testMachineName/", target.UrlString);
            Assert.AreEqual("opcda://testMachineName/", target.ToString());
        }

        [TestMethod]
        public void ToStringTest_Null()
        {
            var target = ServerDescriptor.Null;
            Assert.AreEqual("", target.ToString());
        }

        [TestMethod]
        public void ToStringTest_ServerClassOnly()
        {
            var target = new ServerDescriptor("testServerClass");
            Assert.AreEqual("opcda:testServerClass", target.UrlString);
            Assert.AreEqual("opcda:testServerClass", target.ToString());
        }

        [TestMethod]
        public void ToStringTest_ServerClassOnly_Clsid()
        {
            var target = new ServerDescriptor(TestClsidServerClass);
            Assert.AreEqual("opcda:" + TestClsidServerClass, target.UrlString);
            Assert.AreEqual("opcda:" + TestClsidServerClass, target.ToString());
        }

        [TestMethod]
        public void EqualityTest_NewObjects()
        {
            var target1 = new ServerDescriptor();
            var target2 = new ServerDescriptor();
            Assert.AreEqual(target1.GetHashCode(), target2.GetHashCode());
            Assert.AreEqual(target1, target2);
        }

        [TestMethod]
        public void EqualityTest_Copy()
        {
            var target1 = new ServerDescriptor("http://111.222.33.44/XmlDaSampleServer/Service.asmx");
            AssertUtilities.WriteLine(target1);
            var target2 = new ServerDescriptor(target1);
            AssertUtilities.WriteLine(target2);
            Assert.AreEqual(target1.GetHashCode(), target2.GetHashCode());
            Assert.AreEqual(target1, target2);
        }

        #endregion
    }
}
